@@ -242,7 +242,7 @@ brasero_burn_options_update_no_medium_warning (BraseroBurnOptions *self)
 	/* The user may have forgotten to insert a disc so remind him of that if
 	 * there aren't any other possibility in the selection */
 	brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
-				    _("Please insert a recordable CD or DVD if you don't want to write to an image file."),
+				    _("Please insert a writable CD or DVD if you don't want to write to an image file."),
 				    NULL,
 				    -1,
 				    BRASERO_BURN_OPTIONS_NO_MEDIUM_WARNING);
@@ -298,7 +298,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 					  "response", 
 					  G_CALLBACK (brasero_burn_options_not_ready_dialog_cancel_cb),
 					  self);
-	gtk_widget_show (priv->status_dialog);
+
 			priv->not_ready_id = g_timeout_add_seconds (1,
 								    brasero_burn_options_not_ready_dialog_show_cb,
 								    self);
@@ -359,8 +359,8 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 	}
 	else if (valid == BRASERO_SESSION_NO_OUTPUT) {
 		brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
-					    _("Please insert a recordable CD or DVD."),
-					    _("There is no recordable disc inserted."),
+					    _("Please insert a writable CD or DVD."),
+					    NULL,
 					    -1,
 					    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
@@ -459,7 +459,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 		GtkWidget *message;
 
 		message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
-						      _("Would you like to burn beyond the disc reported capacity?"),
+						      _("Would you like to burn beyond the disc's reported capacity?"),
 						      _("The data size is too large for the disc and you must remove files from the selection otherwise."
 							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognised and therefore need overburn option."
 							"\nNOTE: This option might cause failure."),
@@ -468,7 +468,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 		brasero_notify_button_add (BRASERO_NOTIFY (priv->message_output),
 					   BRASERO_DISC_MESSAGE (message),
 					   _("_Overburn"),
-					   _("Burn beyond the disc reported capacity"),
+					   _("Burn beyond the disc's reported capacity"),
 					   GTK_RESPONSE_OK);
 
 		g_signal_connect (message,
@@ -480,7 +480,7 @@ brasero_burn_options_update_valid (BraseroBurnOptions *self)
 		/* The medium is valid but it's a special case */
 		brasero_notify_message_add (BRASERO_NOTIFY (priv->message_output),
 					    _("The drive that holds the source disc will also be the one used to record."),
-					    _("A new recordable disc will be required once the one currently loaded has been copied."),
+					    _("A new writable disc will be required once the currently loaded one has been copied."),
 					    -1,
 					    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
@@ -500,7 +500,6 @@ static void
 brasero_burn_options_init (BraseroBurnOptions *object)
 {
 	gtk_dialog_set_has_separator (GTK_DIALOG (object), FALSE);
-	gtk_window_set_icon_name (GTK_WINDOW (object), "brasero");
 }
 
 /**
@@ -718,18 +717,21 @@ brasero_status_dialog_uri_has_image (BraseroTrackDataCfg *track,
 					 GTK_BUTTONS_NONE,
 					 "%s",
 					 _("Do you want to create a disc from the contents of the image or with the image file inside?"));
+
 	gtk_window_set_title (GTK_WINDOW (dialog), "");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog),
+	                          gtk_window_get_icon_name (GTK_WINDOW (self)));
 
 	name = brasero_utils_get_uri_name (uri);
 	/* Translators: %s is the name of the image */
-	string = g_strdup_printf (_("There is only one selected file (\"%s\"). It is the image of a disc and its contents can be burnt."), name);
+	string = g_strdup_printf (_("There is only one selected file (\"%s\"). It is the image of a disc and its contents can be burned."), name);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), string);
 	g_free (string);
 	g_free (name);
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Burn as _File"), GTK_RESPONSE_NO);
 
-	button = brasero_utils_make_button (_("Burn _Contents..."),
+	button = brasero_utils_make_button (_("Burn _Contents…"),
 	                                    NULL,
 	                                    "media-optical-burn",
 	                                    GTK_ICON_SIZE_BUTTON);
@@ -845,7 +847,7 @@ brasero_burn_options_setup_disc (BraseroBurnOptions *self)
 	brasero_burn_options_reset (self);
 
 	priv->has_disc = TRUE;
-	gtk_window_set_title (GTK_WINDOW (self), _("CD/DVD Copy Options"));
+	gtk_window_set_title (GTK_WINDOW (self), _("Copy CD/DVD"));
 	brasero_burn_options_add_burn_button (self,
 					      _("_Copy"),
 					      "media-optical-copy");
