@@ -40,6 +40,8 @@
 #include "brasero-caps-burn.h"
 #include "burn-caps.h"
 #include "burn-debug.h"
+#include "brasero-plugin.h"
+#include "brasero-plugin-private.h"
 #include "brasero-plugin-information.h"
 #include "burn-task.h"
 #include "brasero-session-helper.h"
@@ -61,7 +63,7 @@
 		g_set_error (error,						\
 			     BRASERO_BURN_ERROR,				\
 			     BRASERO_BURN_ERROR_GENERAL,			\
-			     _("An internal error occured"));	 		\
+			     _("An internal error occurred"));	 		\
 	BRASERO_BURN_CAPS_NOT_SUPPORTED_LOG (session);				\
 }
 
@@ -489,6 +491,7 @@ brasero_caps_add_processing_plugins_to_task (BraseroBurnSession *session,
 GSList *
 brasero_burn_caps_new_task (BraseroBurnCaps *self,
 			    BraseroBurnSession *session,
+                            BraseroTrackType *temp_output,
 			    GError **error)
 {
 	BraseroPluginProcessFlag position;
@@ -507,19 +510,18 @@ brasero_burn_caps_new_task (BraseroBurnCaps *self,
 	gboolean res;
 
 	/* determine the output and the flags for this task */
-	if (brasero_burn_session_is_dest_file (session)) {
+	if (temp_output) {
+		output.type = temp_output->type;
+		output.subtype.img_format = temp_output->subtype.img_format;
+	}
+	else
+		brasero_burn_session_get_output_type (session, &output);
+
+	if (brasero_track_type_get_has_medium (&output))
+		media = brasero_track_type_get_medium_type (&output);
+	else
 		media = BRASERO_MEDIUM_FILE;
 
-		output.type = BRASERO_TRACK_TYPE_IMAGE;
-		output.subtype.img_format = brasero_burn_session_get_output_format (session);
-	}
-	else {
-		media = brasero_burn_session_get_dest_media (session);
-
-		output.type = BRASERO_TRACK_TYPE_DISC;
-		output.subtype.media = media;
-	}
-
 	if (BRASERO_BURN_SESSION_NO_TMP_FILE (session))
 		flags = BRASERO_PLUGIN_IO_ACCEPT_PIPE;
 	else
@@ -632,27 +634,14 @@ brasero_burn_caps_new_task (BraseroBurnCaps *self,
 
 		link = iter->data;
 
-		/* determine the plugin output */
-		if (iter->next) {
-			BraseroCapsLink *next_link;
-
-			next_link = iter->next->data;
-			if (next_link == link) {
-				/* That's a processing plugin so the output must
-				 * be the exact same as the input, which is not
-				 * necessarily the caps type referred to by the 
-				 * link if the link is amongst the first. In
-				 * that case that's the session input. */
-				memcpy (&plugin_output,
-					&plugin_input,
-					sizeof (BraseroTrackType));
-			}
-			else {
-				memcpy (&plugin_output,
-					&next_link->caps->type,
-					sizeof (BraseroTrackType));
-			}
-		}
+		/* determine the plugin output:
+		 * if it's not the last one it takes the input
+		 * of the next plugin as its output.
+		 * Otherwise it uses the final output type */
+		if (iter->next)
+			memcpy (&plugin_output,
+				&((BraseroCapsLink *) (iter->next->data))->caps->type,
+				sizeof (BraseroTrackType));
 		else
 			memcpy (&plugin_output,
 				&output,
@@ -676,7 +665,7 @@ brasero_burn_caps_new_task (BraseroBurnCaps *self,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			g_slist_foreach (retval, (GFunc) g_object_unref, NULL);
 			g_slist_free (retval);
 			g_slist_free (list);
