@@ -40,6 +40,7 @@
 #include "burn-caps.h"
 #include "burn-debug.h"
 #include "brasero-plugin.h"
+#include "brasero-plugin-private.h"
 #include "brasero-plugin-information.h"
 #include "brasero-session-helper.h"
 
@@ -788,13 +789,6 @@ brasero_burn_session_output_supported (BraseroBurnSession *session,
 	return BRASERO_BURN_OK;
 }
 
-/* This function is not public API yet because it was too
- * late; so use it internally for now. It's mainly for 
- * convenience.*/
-gboolean
-brasero_drive_can_write_media (BraseroDrive *drive,
-                               BraseroMedia media);
-
 /**
  * This is only to be used in case one wants to copy using the same drive.
  * It determines the possible middle image type.
@@ -807,6 +801,7 @@ brasero_burn_caps_is_session_supported_same_src_dest (BraseroBurnCaps *self,
 						      gboolean use_flags)
 {
 	GSList *iter;
+	gboolean supported;
 	BraseroDrive *burner;
 	BraseroTrackType input;
 	BraseroTrackType output;
@@ -835,23 +830,91 @@ brasero_burn_caps_is_session_supported_same_src_dest (BraseroBurnCaps *self,
 	else
 		session_flags = BRASERO_BURN_FLAG_NONE;
 
-	/* Find one available output format */
-	format = BRASERO_IMAGE_FORMAT_CDRDAO;
-	output.type = BRASERO_TRACK_TYPE_IMAGE;
 	burner = brasero_burn_session_get_burner (session);
 
-	for (; format > BRASERO_IMAGE_FORMAT_NONE; format >>= 1) {
-		gboolean supported;
+	/* First see if it works with a stream type */
+	brasero_track_type_set_has_stream (&output);
 
-		output.subtype.img_format = format;
+	/* FIXME! */
+	brasero_track_type_set_stream_format (&output,
+	                                      BRASERO_AUDIO_FORMAT_RAW|
+	                                      BRASERO_METADATA_INFO);
+
+	BRASERO_BURN_LOG_TYPE (&output, "Testing stream type");
+	supported = brasero_caps_try_output (self,
+	                                     session_flags,
+	                                     use_flags,
+	                                     &output,
+	                                     &input,
+	                                     BRASERO_PLUGIN_IO_ACCEPT_FILE);
+	if (supported) {
+		BRASERO_BURN_LOG ("Stream type seems to be supported as output");
+
+		/* This format can be used to create an image. Check if can be
+		 * burnt now. Just find at least one medium. */
+		for (iter = self->priv->caps_list; iter; iter = iter->next) {
+			BraseroCaps *caps;
+			gboolean result;
+
+			caps = iter->data;
+
+			if (caps->type.type != BRASERO_TRACK_TYPE_DISC)
+				continue;
+
+			/* Audio is only supported by CDs */
+			if ((caps->type.subtype.media & BRASERO_MEDIUM_CD) == 0)
+				continue;
+
+			/* This type of disc cannot be burnt; skip them */
+			if (caps->type.subtype.media & BRASERO_MEDIUM_ROM)
+				continue;
+
+			/* Make sure this is supported by the drive */
+			if (!brasero_drive_can_write_media (burner, caps->type.subtype.media))
+				continue;
+
+			result = brasero_caps_find_link (caps,
+							 use_flags,
+							 session_flags,
+							 caps->type.subtype.media,
+							 &output,
+							 BRASERO_PLUGIN_IO_ACCEPT_FILE);
+
+			BRASERO_BURN_LOG_DISC_TYPE (caps->type.subtype.media,
+						    "Tested medium (%s)",
+						    result ? "working":"not working");
+
+			if (result) {
+				if (tmp_type) {
+					tmp_type->type = BRASERO_TRACK_TYPE_STREAM;
+					tmp_type->subtype.stream_format = output.subtype.stream_format;
+				}
+					
+				return BRASERO_BURN_OK;
+			}
+		}
+	}
+	else
+		BRASERO_BURN_LOG ("Stream format not supported as output");
+
+	/* Find one available output format */
+	format = BRASERO_IMAGE_FORMAT_CDRDAO;
+	brasero_track_type_set_has_image (&output);
+
+	for (; format > BRASERO_IMAGE_FORMAT_NONE; format >>= 1) {
+		brasero_track_type_set_image_format (&output, format);
 
 		BRASERO_BURN_LOG_TYPE (&output, "Testing temporary image format");
-		supported = brasero_caps_try_output_with_blanking (self,
-								   session,
-								   &output,
-								   &input,
-								   BRASERO_PLUGIN_IO_ACCEPT_FILE,
-								   use_flags);
+
+		/* Don't need to try blanking here (saves
+		 * a few lines of debug) since that is an 
+		 * image */
+		supported = brasero_caps_try_output (self,
+		                                     session_flags,
+		                                     use_flags,
+		                                     &output,
+		                                     &input,
+		                                     BRASERO_PLUGIN_IO_ACCEPT_FILE);
 		if (!supported)
 			continue;
 
@@ -895,7 +958,7 @@ brasero_burn_caps_is_session_supported_same_src_dest (BraseroBurnCaps *self,
 			if (result) {
 				if (tmp_type) {
 					tmp_type->type = BRASERO_TRACK_TYPE_IMAGE;
-					tmp_type->subtype.img_format = format;
+					tmp_type->subtype.img_format = brasero_track_type_get_image_format (&output);
 				}
 					
 				return BRASERO_BURN_OK;
@@ -1344,12 +1407,6 @@ brasero_caps_get_flags (BraseroCaps *caps,
 	return retval;
 }
 
-/* FIXME: make this public */
-gboolean
-brasero_medium_can_use_sao (BraseroMedium *medium);
-gboolean
-brasero_medium_can_use_tao (BraseroMedium *medium);
-
 static void
 brasero_medium_supported_flags (BraseroMedium *medium,
 				BraseroBurnFlag *supported_flags,
@@ -1471,7 +1528,7 @@ brasero_caps_get_flags_for_disc (BraseroBurnCaps *self,
 		supported_flags &= ~BRASERO_BURN_FLAG_RAW;
 
 	if ((supported_flags & BRASERO_BURN_FLAG_DAO)
-	&&   input->type == BRASERO_TRACK_TYPE_STREAM
+	&&   brasero_track_type_get_has_stream (input)
 	&&  (input->subtype.img_format & BRASERO_METADATA_INFO)) {
 		/* In this case, DAO is compulsory if we want to write CD-TEXT */
 		compulsory_flags |= BRASERO_BURN_FLAG_DAO;
@@ -1624,16 +1681,109 @@ brasero_burn_caps_get_flags_for_medium (BraseroBurnCaps *self,
 	return BRASERO_BURN_OK;
 }
 
+static BraseroBurnResult
+brasero_burn_caps_get_flags_same_src_dest_for_types (BraseroBurnCaps *self,
+                                                     BraseroBurnSession *session,
+                                                     BraseroTrackType *input,
+                                                     BraseroTrackType *output,
+                                                     BraseroBurnFlag *supported_ret,
+                                                     BraseroBurnFlag *compulsory_ret)
+{
+	GSList *iter;
+	gboolean type_supported;
+	BraseroBurnFlag session_flags;
+	BraseroBurnFlag supported_final = BRASERO_BURN_FLAG_NONE;
+	BraseroBurnFlag compulsory_final = BRASERO_BURN_FLAG_ALL;
+
+	/* NOTE: there is no need to get the flags here since there are
+	 * no specific DISC => IMAGE flags. We just want to know if that
+	 * is possible. */
+	BRASERO_BURN_LOG_TYPE (output, "Testing temporary image format");
+
+	/* Here there is no need to try blanking as there
+	 * is no disc (saves a few debug lines) */
+	type_supported = brasero_caps_try_output (self,
+	                                          BRASERO_BURN_FLAG_NONE,
+	                                          FALSE,
+	                                          output,
+	                                          input,
+	                                          BRASERO_PLUGIN_IO_ACCEPT_FILE);
+	if (!type_supported) {
+		BRASERO_BURN_LOG_TYPE (output, "Format not supported");
+		return FALSE;
+	}
+
+	session_flags = brasero_burn_session_get_flags (session);
+
+	/* This format can be used to create an image. Check if can be
+	 * burnt now. Just find at least one medium. */
+	type_supported = FALSE;
+	for (iter = self->priv->caps_list; iter; iter = iter->next) {
+		BraseroBurnFlag compulsory;
+		BraseroBurnFlag supported;
+		BraseroBurnResult result;
+		BraseroCaps *caps;
+
+		caps = iter->data;
+		if (caps->type.type != BRASERO_TRACK_TYPE_DISC)
+			continue;
+
+		/* This type of disc cannot be burnt; skip them */
+		if (caps->type.subtype.media & BRASERO_MEDIUM_ROM)
+			continue;
+
+		if ((caps->type.subtype.media & BRASERO_MEDIUM_CD) == 0) {
+			if (brasero_track_type_get_has_image (output)) {
+				BraseroImageFormat format;
+
+				format = brasero_track_type_get_image_format (output);
+				/* These three types only work with CDs. */
+				if (format == BRASERO_IMAGE_FORMAT_CDRDAO
+				||   format == BRASERO_IMAGE_FORMAT_CLONE
+				||   format == BRASERO_IMAGE_FORMAT_CUE)
+					continue;
+			}
+			else if (brasero_track_type_get_has_stream (output))
+				continue;
+		}
+
+		/* Merge all available flags for each possible medium type */
+		supported = BRASERO_BURN_FLAG_NONE;
+		compulsory = BRASERO_BURN_FLAG_NONE;
+
+		result = brasero_caps_get_flags_for_disc (self,
+		                                          session_flags,
+		                                          caps->type.subtype.media,
+							  output,
+							  &supported,
+							  &compulsory);
+
+		if (result != BRASERO_BURN_OK)
+			continue;
+
+		type_supported = TRUE;
+		supported_final |= supported;
+		compulsory_final &= compulsory;
+	}
+
+	BRASERO_BURN_LOG_TYPE (output, "Format supported %i", type_supported);
+	if (!type_supported)
+		return FALSE;
+
+	*supported_ret = supported_final;
+	*compulsory_ret = compulsory_final;
+	return type_supported;
+}
+
 static BraseroBurnResult
 brasero_burn_caps_get_flags_same_src_dest (BraseroBurnCaps *self,
 					   BraseroBurnSession *session,
 					   BraseroBurnFlag *supported_ret,
 					   BraseroBurnFlag *compulsory_ret)
 {
-	GSList *iter;
-	gboolean copy_supported;
 	BraseroTrackType input;
 	BraseroTrackType output;
+	gboolean copy_supported;
 	BraseroImageFormat format;
 	BraseroBurnFlag session_flags;
 	BraseroBurnFlag supported_final = BRASERO_BURN_FLAG_NONE;
@@ -1655,80 +1805,48 @@ brasero_burn_caps_get_flags_same_src_dest (BraseroBurnCaps *self,
 	if (session_flags & (BRASERO_BURN_FLAG_MERGE|BRASERO_BURN_FLAG_NO_TMP_FILES))
 		return BRASERO_BURN_NOT_SUPPORTED;
 
+	/* Check for stream type */
+	brasero_track_type_set_has_stream (&output);
+	/* FIXME! */
+	brasero_track_type_set_stream_format (&output,
+	                                      BRASERO_AUDIO_FORMAT_RAW|
+	                                      BRASERO_METADATA_INFO);
+	copy_supported = brasero_burn_caps_get_flags_same_src_dest_for_types (self,
+	                                                                      session,
+	                                                                      &input,
+	                                                                      &output,
+	                                                                      &supported_final,
+	                                                                      &compulsory_final);
+
 	/* Check flags for all available format */
 	format = BRASERO_IMAGE_FORMAT_CDRDAO;
-	output.type = BRASERO_TRACK_TYPE_IMAGE;
-
-	copy_supported = FALSE;
+	brasero_track_type_set_has_image (&output);
 	for (; format > BRASERO_IMAGE_FORMAT_NONE; format >>= 1) {
-		BraseroBurnResult result;
 		gboolean format_supported;
+		BraseroBurnFlag supported;
+		BraseroBurnFlag compulsory;
 
 		/* check if this image type is possible given the current flags */
 		if (format != BRASERO_IMAGE_FORMAT_CLONE
 		&& (session_flags & BRASERO_BURN_FLAG_RAW))
 			continue;
 
-		output.subtype.img_format = format;
+		brasero_track_type_set_image_format (&output, format);
 
-		/* NOTE: there is no need to get the flags here since there are
-		 * no specific DISC => IMAGE flags. We just want to know if that
-		 * is possible. */
-		BRASERO_BURN_LOG_TYPE (&output, "Testing temporary image format");
-		format_supported = brasero_caps_try_output_with_blanking (self,
-									  session,
-									  &output,
-									  &input,
-									  BRASERO_PLUGIN_IO_ACCEPT_FILE,
-									  FALSE);
-		if (!format_supported) {
-			BRASERO_BURN_LOG_TYPE (&output, "Format not supported");
+		supported = BRASERO_BURN_FLAG_NONE;
+		compulsory = BRASERO_BURN_FLAG_NONE;
+		format_supported = brasero_burn_caps_get_flags_same_src_dest_for_types (self,
+		                                                                        session,
+		                                                                        &input,
+		                                                                        &output,
+		                                                                        &supported,
+		                                                                        &compulsory);
+		if (!format_supported)
 			continue;
-		}
 
-		/* This format can be used to create an image. Check if can be
-		 * burnt now. Just find at least one medium. */
-		format_supported = FALSE;
-		for (iter = self->priv->caps_list; iter; iter = iter->next) {
-			BraseroBurnFlag compulsory;
-			BraseroBurnFlag supported;
-			BraseroCaps *caps;
-
-			caps = iter->data;
-			if (caps->type.type != BRASERO_TRACK_TYPE_DISC)
-				continue;
-
-			/* This type of disc cannot be burnt; skip them */
-			if (caps->type.subtype.media & BRASERO_MEDIUM_ROM)
-				continue;
-
-			/* These three types only work with CDs. Skip the rest. */
-			if ((output.subtype.img_format == BRASERO_IMAGE_FORMAT_CDRDAO
-			||   output.subtype.img_format == BRASERO_IMAGE_FORMAT_CLONE
-			||   output.subtype.img_format == BRASERO_IMAGE_FORMAT_CUE)
-			&& (caps->type.subtype.media & BRASERO_MEDIUM_CD) == 0)
-				continue;
-
-			/* Merge all available flags for each possible medium type */
-			supported = BRASERO_BURN_FLAG_NONE;
-			compulsory = BRASERO_BURN_FLAG_NONE;
-			result = brasero_burn_caps_get_flags_for_medium (self,
-									 caps->type.subtype.media,
-									 session_flags,
-									 &output,
-									 &supported,
-									 &compulsory);
-			if (result != BRASERO_BURN_OK)
-				continue;
-
-			format_supported = TRUE;
-			supported_final |= supported;
-			compulsory_final &= compulsory;
-		}
-
-		BRASERO_BURN_LOG_TYPE (&output, "Format supported %i", format_supported);
-		if (format_supported)
-			copy_supported = TRUE;
+		copy_supported = TRUE;
+		supported_final |= supported;
+		compulsory_final &= compulsory;
 	}
 
 	if (!copy_supported)
@@ -1736,7 +1854,55 @@ brasero_burn_caps_get_flags_same_src_dest (BraseroBurnCaps *self,
 
 	*supported_ret |= supported_final;
 	*compulsory_ret |= compulsory_final;
-	
+
+	/* we also add these two flags as being supported
+	 * since they could be useful and can't be tested
+	 * until the disc is inserted which it is not at the
+	 * moment */
+	(*supported_ret) |= (BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE|
+					 BRASERO_BURN_FLAG_FAST_BLANK);
+
+	if (brasero_track_type_get_medium_type (&input) & BRASERO_MEDIUM_HAS_AUDIO) {
+		/* This is a special case for audio discs.
+		 * Since they may contain CD-TEXT and
+		 * since CD-TEXT can only be written with
+		 * DAO then we must make sure the user
+		 * can't use MULTI since then DAO is
+		 * impossible. */
+		(*compulsory_ret) |= BRASERO_BURN_FLAG_DAO;
+
+		/* This is just to make sure */
+		(*supported_ret) &= (~BRASERO_BURN_FLAG_MULTI);
+		(*compulsory_ret) &= (~BRASERO_BURN_FLAG_MULTI);
+	}
+
+	return BRASERO_BURN_OK;
+}
+
+/**
+ * This is meant to use as internal API
+ */
+BraseroBurnResult
+brasero_caps_session_get_file_flags (BraseroTrackType *input,
+                                     BraseroTrackType *output,
+                                     BraseroBurnFlag *supported,
+                                     BraseroBurnFlag *compulsory)
+{
+	BraseroBurnFlag compulsory_flags = BRASERO_BURN_FLAG_NONE;
+	BraseroBurnFlag supported_flags = BRASERO_BURN_FLAG_CHECK_SIZE|BRASERO_BURN_FLAG_NOGRACE;
+
+	BRASERO_BURN_LOG ("FLAGS: image required");
+
+	/* In this case no APPEND/MERGE is possible */
+	if (brasero_track_type_get_has_medium (input))
+		supported_flags |= BRASERO_BURN_FLAG_EJECT;
+
+	*supported = supported_flags;
+	*compulsory = compulsory_flags;
+
+	BRASERO_BURN_LOG_FLAGS (supported_flags, "FLAGS: supported");
+	BRASERO_BURN_LOG_FLAGS (compulsory_flags, "FLAGS: compulsory");
+
 	return BRASERO_BURN_OK;
 }
 
@@ -1783,17 +1949,14 @@ brasero_burn_session_get_burn_flags (BraseroBurnSession *session,
 				    "FLAGS: searching available flags for input");
 
 	if (brasero_burn_session_is_dest_file (session)) {
+		BraseroTrackType *output;
+
 		BRASERO_BURN_LOG ("FLAGS: image required");
 
-		/* In this case no APPEND/MERGE is possible */
-		if (brasero_track_type_get_has_medium (input))
-			supported_flags |= BRASERO_BURN_FLAG_EJECT;
-
-		*supported = supported_flags;
-		*compulsory = compulsory_flags;
-
-		BRASERO_BURN_LOG_FLAGS (supported_flags, "FLAGS: supported");
-		BRASERO_BURN_LOG_FLAGS (compulsory_flags, "FLAGS: compulsory");
+		output = brasero_track_type_new ();
+		brasero_burn_session_get_output_type (session, output);
+		brasero_caps_session_get_file_flags (input, output, supported, compulsory);
+		brasero_track_type_free (output);
 
 		brasero_track_type_free (input);
 		g_object_unref (self);
