@@ -59,8 +59,6 @@
 #include "brasero-session.h"
 #include "brasero-session-cfg.h"
 
-#define BRASERO_SECTORS_TO_DURATION(sectors)	(guint64) ((sectors) * 1000000000LL / 75LL)
-
 typedef struct _BraseroDestSelectionPrivate BraseroDestSelectionPrivate;
 struct _BraseroDestSelectionPrivate
 {
@@ -640,7 +638,7 @@ brasero_dest_selection_format_medium_string (BraseroMediumSelection *selection,
 			 * destination disc a new one (once the source has been
 			 * copied) which is to be inserted in the drive currently
 			 * holding the source disc */
-			label = g_strdup_printf (_("New disc in the burner holding source disc"));
+			label = g_strdup_printf (_("New disc in the burner holding the source disc"));
 			g_free (medium_name);
 
 			brasero_medium_selection_update_used_space (BRASERO_MEDIUM_SELECTION (selection),
@@ -702,7 +700,7 @@ brasero_dest_selection_format_medium_string (BraseroMediumSelection *selection,
 	else if (brasero_track_type_get_has_stream (input)
 	|| (brasero_track_type_get_has_medium (input)
 	&& (brasero_track_type_get_medium_type (input) & BRASERO_MEDIUM_HAS_AUDIO)))
-		size_string = brasero_units_get_time_string (BRASERO_SECTORS_TO_DURATION (blocks),
+		size_string = brasero_units_get_time_string (BRASERO_BYTES_TO_DURATION (size_bytes - session_bytes),
 							     TRUE,
 							     TRUE);
 	else
