@@ -232,7 +232,7 @@ brasero_session_cfg_set_output_image (BraseroBurnSession *session,
 
 	if (format & BRASERO_IMAGE_FORMAT_BIN) {
 		dot = g_utf8_strrchr (image, -1, '.');
-		if (strcmp (suffixes [0], dot)) {
+		if (!dot || strcmp (suffixes [0], dot)) {
 			gboolean res;
 
 			res = brasero_session_cfg_wrong_extension_signal (BRASERO_SESSION_CFG (session));
@@ -255,7 +255,7 @@ brasero_session_cfg_set_output_image (BraseroBurnSession *session,
 		dot = g_utf8_strrchr (toc, -1, '.');
 
 		if (format & BRASERO_IMAGE_FORMAT_CLONE
-		&& strcmp (suffixes [1], dot)) {
+		&& (!dot || strcmp (suffixes [1], dot))) {
 			gboolean res;
 
 			res = brasero_session_cfg_wrong_extension_signal (BRASERO_SESSION_CFG (session));
@@ -271,7 +271,7 @@ brasero_session_cfg_set_output_image (BraseroBurnSession *session,
 			}
 		}
 		else if (format & BRASERO_IMAGE_FORMAT_CUE
-		     && strcmp (suffixes [2], dot)) {
+		     && (!dot || strcmp (suffixes [2], dot))) {
 			gboolean res;
 
 			res = brasero_session_cfg_wrong_extension_signal (BRASERO_SESSION_CFG (session));
@@ -287,7 +287,7 @@ brasero_session_cfg_set_output_image (BraseroBurnSession *session,
 			}
 		}
 		else if (format & BRASERO_IMAGE_FORMAT_CDRDAO
-		     && strcmp (suffixes [3], dot)) {
+		     && (!dot || strcmp (suffixes [3], dot))) {
 			gboolean res;
 
 			res = brasero_session_cfg_wrong_extension_signal (BRASERO_SESSION_CFG (session));
@@ -607,6 +607,37 @@ brasero_session_cfg_set_drive_properties_default_flags (BraseroSessionCfg *self)
 						     &priv->compulsory);
 	}
 
+#if 0
+	
+	/* NOTE: Stop setting DAO here except if it
+	 * is declared compulsory (but that's handled
+	 * somewhere else) or if it was explicity set.
+	 * If we set it just  by  default when it's
+	 * supported but not compulsory, MULTI
+	 * becomes not supported anymore.
+	 * For data the only way it'd be really useful
+	 * is if we wanted to fit a selection on the disc.
+	 * The problem here is that we don't know
+	 * what the size of the final image is going
+	 * to be.
+	 * For images there are cases when after 
+	 * writing an image the user may want to
+	 * add some more data to it later. As in the
+	 * case of data the only way this flag would
+	 * be useful would be to help fit the image
+	 * on the disc. But I doubt it would really
+	 * help a lot.
+	 * For audio we need it to write things like
+	 * CD-TEXT but in this case the backend
+	 * will return it as compulsory. */
+
+	/* Another case when this flag is needed is
+	 * for DVD-RW quick blanked as they only
+	 * support DAO. But there again this should
+	 * be covered by the backend that should
+	 * return DAO as compulsory. */
+
+	/* Leave the code as a reminder. */
 	/* When copying with same drive don't set write mode, it'll be set later */
 	if (!brasero_burn_session_same_src_dest_drive (BRASERO_BURN_SESSION (self))
 	&&  !(media & BRASERO_MEDIUM_DVD)) {
@@ -623,9 +654,10 @@ brasero_session_cfg_set_drive_properties_default_flags (BraseroSessionCfg *self)
 							     &priv->compulsory);
 
 			/* NOTE: after setting DAO, some flags may become
-			 * compulsory like BLANK_BEFORE for CDRW with data */
+			 * compulsory like MULTI. */
 		}
 	}
+#endif
 }
 
 static void
@@ -648,12 +680,16 @@ brasero_session_cfg_set_drive_properties_flags (BraseroSessionCfg *self,
 	BRASERO_BURN_LOG_FLAGS (flags, "New should be");
 
 	drive = brasero_burn_session_get_burner (BRASERO_BURN_SESSION (self));
-	if (!drive)
+	if (!drive) {
+		BRASERO_BURN_LOG ("No drive");
 		return;
+	}
 
 	medium = brasero_drive_get_medium (drive);
-	if (!medium)
+	if (!medium) {
+		BRASERO_BURN_LOG ("No medium");
 		return;
+	}
 
 	media = brasero_medium_get_status (medium);
 
@@ -676,7 +712,7 @@ brasero_session_cfg_set_drive_properties_flags (BraseroSessionCfg *self,
 
 	for (flag = BRASERO_BURN_FLAG_EJECT; flag < BRASERO_BURN_FLAG_LAST; flag <<= 1) {
 		/* see if this flag was originally set */
-		if (!(flags & flag))
+		if ((flags & flag) == 0)
 			continue;
 
 		/* Don't set write modes now in this case */
@@ -706,6 +742,21 @@ brasero_session_cfg_set_drive_properties_flags (BraseroSessionCfg *self,
 		}
 	}
 
+	if (original_flags & BRASERO_BURN_FLAG_DAO
+	&&  priv->supported & BRASERO_BURN_FLAG_DAO) {
+		/* Only set DAO if it was explicitely requested */
+		brasero_burn_session_add_flag (BRASERO_BURN_SESSION (self), BRASERO_BURN_FLAG_DAO);
+
+		priv->supported = BRASERO_BURN_FLAG_NONE;
+		priv->compulsory = BRASERO_BURN_FLAG_NONE;
+		brasero_burn_session_get_burn_flags (BRASERO_BURN_SESSION (self),
+						     &priv->supported,
+						     &priv->compulsory);
+
+		/* NOTE: after setting DAO, some flags may become
+		 * compulsory like MULTI. */
+	}
+
 	brasero_session_cfg_set_drive_properties_default_flags (self);
 
 	/* allow flag changed signal again */
@@ -755,11 +806,15 @@ brasero_session_cfg_set_drive_properties (BraseroSessionCfg *self)
 
 	priv = BRASERO_SESSION_CFG_PRIVATE (self);
 
+	BRASERO_BURN_LOG ("Restoring session properties");
+
 	/* The next two must work as they were checked earlier */
 	drive = brasero_burn_session_get_burner (BRASERO_BURN_SESSION (self));
 	medium = brasero_drive_get_medium (drive);
-	if (!medium || brasero_medium_get_status (medium) == BRASERO_MEDIUM_NONE)
+	if (!medium || brasero_medium_get_status (medium) == BRASERO_MEDIUM_NONE) {
+		BRASERO_BURN_LOG ("No media");
 		return;
+	}
 
 	/* Update/set the rate */
 	client = gconf_client_get_default ();
@@ -971,9 +1026,7 @@ brasero_session_cfg_set_tracks_audio_format (BraseroBurnSession *session,
 }
 
 static void
-brasero_session_cfg_update (BraseroSessionCfg *self,
-			    gboolean update,
-			    gboolean check)
+brasero_session_cfg_update (BraseroSessionCfg *self)
 {
 	BraseroTrackType *source = NULL;
 	BraseroSessionCfgPrivate *priv;
@@ -1079,8 +1132,6 @@ brasero_session_cfg_update (BraseroSessionCfg *self,
 		return;
 	}
 
-	/* FIXME: another easy error to catch: AUDIO project with a DVD */
-
 	/* make sure there is an output set */
 	burner = brasero_burn_session_get_burner (BRASERO_BURN_SESSION (self));
 	if (!burner) {
@@ -1169,30 +1220,38 @@ brasero_session_cfg_update (BraseroSessionCfg *self,
 
 			/* NOTE: this is the same as brasero_burn_session_can_burn () */
 			result = brasero_burn_session_get_tmp_image_type_same_src_dest (BRASERO_BURN_SESSION (self), tmp_type);
-			if (result == BRASERO_BURN_OK)
-				format = brasero_track_type_get_image_format (tmp_type);
+			if (result == BRASERO_BURN_OK) {
+				if (brasero_track_type_get_has_image (tmp_type)) {
+					format = brasero_track_type_get_image_format (tmp_type);
+					priv->CD_TEXT_modified = (format & (BRASERO_IMAGE_FORMAT_CDRDAO|BRASERO_IMAGE_FORMAT_CUE)) == 0;
+				}
+				else if (brasero_track_type_get_has_stream (tmp_type)) {
+					/* FIXME: for the moment
+					 * we consider that this
+					 * type will always allow
+					 * to copy CD-TEXT */
+					priv->CD_TEXT_modified = FALSE;
+				}
+				else
+					priv->CD_TEXT_modified = TRUE;
+			}
 			else
-				format = BRASERO_IMAGE_FORMAT_NONE;
+				priv->CD_TEXT_modified = TRUE;
 
 			brasero_track_type_free (tmp_type);
 
 			BRASERO_BURN_LOG ("Temporary image type %i", format);
 		}
 		else {
-			result = brasero_burn_session_can_burn (BRASERO_BURN_SESSION (self),
-			                                        FALSE);
+			result = brasero_burn_session_can_burn (BRASERO_BURN_SESSION (self), FALSE);
 			format = brasero_burn_session_get_output_format (BRASERO_BURN_SESSION (self));
+			priv->CD_TEXT_modified = (format & (BRASERO_IMAGE_FORMAT_CDRDAO|BRASERO_IMAGE_FORMAT_CUE)) == 0;
 		}
-
-		priv->CD_TEXT_modified = FALSE;
-		if (!(format & (BRASERO_IMAGE_FORMAT_CDRDAO|BRASERO_IMAGE_FORMAT_CUE)))
-			priv->CD_TEXT_modified = TRUE;
 	}
 	else {
 		/* Don't use flags as they'll be adapted later. */
 		priv->CD_TEXT_modified = FALSE;
-		result = brasero_burn_session_can_burn (BRASERO_BURN_SESSION (self),
-							FALSE);
+		result = brasero_burn_session_can_burn (BRASERO_BURN_SESSION (self), FALSE);
 	}
 
 	if (result != BRASERO_BURN_OK) {
@@ -1237,11 +1296,6 @@ brasero_session_cfg_update (BraseroSessionCfg *self,
 						  BRASERO_BURN_FLAG_DUMMY|
 						  BRASERO_BURN_FLAG_NO_TMP_FILES);
 
-	if (update)
-		brasero_session_cfg_set_drive_properties (self);
-	else if (check)
-		brasero_session_cfg_check_drive_settings (self);
-
 	priv->configuring = FALSE;
 
 	/* Finally check size */
@@ -1265,14 +1319,23 @@ brasero_session_cfg_session_loaded (BraseroTrackDataCfg *track,
 				    gboolean is_loaded,
 				    BraseroSessionCfg *session)
 {
+	BraseroBurnFlag session_flags;
+	BraseroSessionCfgPrivate *priv;
+
+	priv = BRASERO_SESSION_CFG_PRIVATE (session);
+	if (priv->disabled)
+		return;
+
+	session_flags = brasero_burn_session_get_flags (BRASERO_BURN_SESSION (session));
 	if (is_loaded) {
 		/* Set the correct medium and add the flag */
 		brasero_burn_session_set_burner (BRASERO_BURN_SESSION (session),
 						 brasero_medium_get_drive (medium));
 
-		brasero_session_cfg_add_drive_properties_flags (session, BRASERO_BURN_FLAG_MERGE);
+		if ((session_flags & BRASERO_BURN_FLAG_MERGE) == 0)
+			brasero_session_cfg_add_drive_properties_flags (session, BRASERO_BURN_FLAG_MERGE);
 	}
-	else
+	else if ((session_flags & BRASERO_BURN_FLAG_MERGE) != 0)
 		brasero_session_cfg_rm_drive_properties_flags (session, BRASERO_BURN_FLAG_MERGE);
 }
 
@@ -1297,11 +1360,9 @@ brasero_session_cfg_track_added (BraseroBurnSession *session,
 	 * - reload saved flags
 	 * - check if all flags are thereafter supported
 	 * - check available formats for path
-	 * - set one path
-	 */
-	brasero_session_cfg_update (BRASERO_SESSION_CFG (session),
-				    TRUE,
-				    FALSE);
+	 * - set one path */
+	brasero_session_cfg_update (BRASERO_SESSION_CFG (session));
+	brasero_session_cfg_set_drive_properties (BRASERO_SESSION_CFG (session));
 }
 
 static void
@@ -1327,9 +1388,8 @@ brasero_session_cfg_track_removed (BraseroBurnSession *session,
 	 * - check available formats for path
 	 * - set one path
 	 */
-	brasero_session_cfg_update (BRASERO_SESSION_CFG (session),
-				    TRUE,
-				    FALSE);
+	brasero_session_cfg_update (BRASERO_SESSION_CFG (session));
+	brasero_session_cfg_set_drive_properties (BRASERO_SESSION_CFG (session));
 }
 
 static void
@@ -1349,9 +1409,8 @@ brasero_session_cfg_track_changed (BraseroBurnSession *session,
 	 * - check available formats for path
 	 * - set one path
 	 */
-	brasero_session_cfg_update (BRASERO_SESSION_CFG (session),
-				    TRUE,
-				    FALSE);
+	brasero_session_cfg_update (BRASERO_SESSION_CFG (session));
+	brasero_session_cfg_set_drive_properties (BRASERO_SESSION_CFG (session));
 }
 
 static void
@@ -1405,11 +1464,9 @@ brasero_session_cfg_output_changed (BraseroBurnSession *session,
 	/* In this case need to :
 	 * - load flags 
 	 * - check if all flags are thereafter supported
-	 * - for images, set a path if it wasn't already set
-	 */
-	brasero_session_cfg_update (BRASERO_SESSION_CFG (session),
-				    TRUE,
-				    FALSE);
+	 * - for images, set a path if it wasn't already set */
+	brasero_session_cfg_update (BRASERO_SESSION_CFG (session));
+	brasero_session_cfg_set_drive_properties (BRASERO_SESSION_CFG (session));
 }
 
 static void
@@ -1426,9 +1483,8 @@ brasero_session_cfg_caps_changed (BraseroPluginManager *manager,
 	 * - new flags are supported or not supported anymore
 	 * - new image types as input/output are supported
 	 * - if the current set of flags/input/output still works */
-	brasero_session_cfg_update (self,
-				    FALSE,
-				    TRUE);
+	brasero_session_cfg_update (self);
+	brasero_session_cfg_check_drive_settings (self);
 }
 
 static void
@@ -1471,9 +1527,7 @@ brasero_session_cfg_add_flags (BraseroSessionCfg *self,
 		return;
 
 	brasero_session_cfg_add_drive_properties_flags (self, flags);
-	brasero_session_cfg_update (self,
-				    FALSE,
-				    FALSE);
+	brasero_session_cfg_update (self);
 }
 
 /**
@@ -1507,9 +1561,7 @@ brasero_session_cfg_remove_flags (BraseroSessionCfg *self,
 	if (drive && brasero_drive_get_medium (drive))
 		brasero_session_cfg_save_drive_flags (self, brasero_drive_get_medium (drive));
 
-	brasero_session_cfg_update (self,
-				    FALSE,
-				    FALSE);
+	brasero_session_cfg_update (self);
 }
 
 /**
