@@ -43,22 +43,23 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
+#include "brasero-session.h"
+#include "brasero-session-helper.h"
 
 #include "burn-basics.h"
 #include "burn-debug.h"
 #include "libbrasero-marshal.h"
 #include "burn-image-format.h"
+#include "brasero-track-type-private.h"
 
 #include "brasero-medium.h"
 #include "brasero-drive.h"
 #include "brasero-medium-monitor.h"
 
 #include "brasero-tags.h"
-#include "brasero-session.h"
 #include "brasero-track.h"
 #include "brasero-track-disc.h"
 
-
 G_DEFINE_TYPE (BraseroBurnSession, brasero_burn_session, G_TYPE_OBJECT);
 #define BRASERO_BURN_SESSION_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_BURN_SESSION, BraseroBurnSessionPrivate))
 
@@ -79,7 +80,7 @@ struct _BraseroSessionSetting {
 	/**
 	 * Used when outputting an image instead of burning
 	 */
-	BraseroImageFormat format;
+	BraseroTrackType output;
 	gchar *image;
 	gchar *toc;
 
@@ -581,20 +582,29 @@ BraseroBurnResult
 brasero_burn_session_get_input_type (BraseroBurnSession *self,
 				     BraseroTrackType *type)
 {
-	BraseroTrack *track;
+	GSList *iter;
+	BraseroStreamFormat format;
 	BraseroBurnSessionPrivate *priv;
 
 	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (self), BRASERO_BURN_ERR);
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 
-	if (!priv->tracks)
-		return BRASERO_BURN_OK;
-
 	/* there can be many tracks (in case of audio) but they must be
-	 * all of the same kind for the moment */
-	track = priv->tracks->data;
-	brasero_track_get_track_type (track, type);
+	 * all of the same kind for the moment. Yet their subtypes may
+	 * be different. */
+	format = BRASERO_AUDIO_FORMAT_NONE;
+	for (iter = priv->tracks; iter; iter = iter->next) {
+		BraseroTrack *track;
+
+		track = iter->data;
+		brasero_track_get_track_type (track, type);
+		if (brasero_track_type_get_has_stream (type))
+			format |= brasero_track_type_get_stream_format (type);
+	}
+
+	if (brasero_track_type_get_has_stream (type))
+		brasero_track_type_set_image_format (type, format);
 
 	return BRASERO_BURN_OK;
 }
@@ -765,6 +775,9 @@ brasero_burn_session_get_rate (BraseroBurnSession *self)
 		return 0;
 
 	medium = brasero_drive_get_medium (priv->settings->burner);
+	if (!medium)
+		return 0;
+
 	max_rate = brasero_medium_get_max_write_speed (medium);
 	if (priv->settings->rate <= 0)
 		return max_rate;
@@ -772,6 +785,40 @@ brasero_burn_session_get_rate (BraseroBurnSession *self)
 		return MIN (max_rate, priv->settings->rate);
 }
 
+/**
+ * brasero_burn_session_get_output_type:
+ * @session: a #BraseroBurnSession
+ * @output: a #BraseroTrackType or NULL
+ *
+ * This function returns the type of output set for the session.
+ *
+ * Return value: a #BraseroBurnResult.
+ * BRASERO_BURN_OK if it was successful; BRASERO_BURN_NOT_READY if no setting has been set; BRASERO_BURN_ERR otherwise.
+ **/
+BraseroBurnResult
+brasero_burn_session_get_output_type (BraseroBurnSession *self,
+                                      BraseroTrackType *output)
+{
+	BraseroBurnSessionPrivate *priv;
+
+	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (self), BRASERO_BURN_ERR);
+
+	priv = BRASERO_BURN_SESSION_PRIVATE (self);
+	if (!priv->settings->burner)
+		return BRASERO_BURN_NOT_READY;
+
+	if (brasero_drive_is_fake (priv->settings->burner)) {
+		output->type = BRASERO_TRACK_TYPE_IMAGE;
+		output->subtype.img_format = brasero_burn_session_get_output_format (self);
+	}
+	else {
+		output->type = BRASERO_TRACK_TYPE_DISC;
+		output->subtype.media = brasero_medium_get_status (brasero_drive_get_medium (priv->settings->burner));
+	}
+
+	return BRASERO_BURN_OK;
+}
+
 /**
  * brasero_burn_session_get_output:
  * @session: a #BraseroBurnSession
@@ -899,7 +946,7 @@ brasero_burn_session_get_output_format_real (BraseroBurnSession *self)
 	BraseroBurnSessionPrivate *priv;
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
-	return priv->settings->format;
+	return brasero_track_type_get_image_format (&(priv->settings->output));
 }
 
 /**
@@ -933,7 +980,25 @@ brasero_burn_session_set_image_output_real (BraseroBurnSession *self,
 	else
 		priv->settings->toc = NULL;
 
-	priv->settings->format = format;
+	brasero_track_type_set_has_image (&(priv->settings->output));
+	brasero_track_type_set_image_format (&(priv->settings->output),  format);
+}
+
+static void
+brasero_burn_session_set_fake_drive (BraseroBurnSession *self)
+{
+	BraseroMediumMonitor *monitor;
+	BraseroDrive *drive;
+	GSList *list;
+
+	/* NOTE: changing/changed signals are handled in
+	 * set_burner (). */
+	monitor = brasero_medium_monitor_get_default ();
+	list = brasero_medium_monitor_get_media (monitor, BRASERO_MEDIA_TYPE_FILE);
+	drive = brasero_medium_get_drive (list->data);
+	brasero_burn_session_set_burner (self, drive);
+	g_object_unref (monitor);
+	g_slist_free (list);
 }
 
 static BraseroBurnResult
@@ -946,48 +1011,24 @@ brasero_burn_session_set_output_image_real (BraseroBurnSession *self,
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 
-	if (priv->settings->format == format
+	if (brasero_track_type_get_has_image (&(priv->settings->output))
+	&& brasero_track_type_get_image_format (&(priv->settings->output)) == format
 	&&  BRASERO_STR_EQUAL (image, priv->settings->image)
 	&&  BRASERO_STR_EQUAL (toc, priv->settings->toc)) {
-		if (!BRASERO_BURN_SESSION_WRITE_TO_FILE (priv)) {
-			BraseroMediumMonitor *monitor;
-			BraseroDrive *drive;
-			GSList *list;
-
-			/* NOTE: changing/changed signals are handled in
-			 * set_burner (). */
-			monitor = brasero_medium_monitor_get_default ();
-			list = brasero_medium_monitor_get_media (monitor, BRASERO_MEDIA_TYPE_FILE);
-			drive = brasero_medium_get_drive (list->data);
-			brasero_burn_session_set_burner (self, drive);
-			g_object_unref (monitor);
-			g_slist_free (list);
-		}
+		if (!BRASERO_BURN_SESSION_WRITE_TO_FILE (priv))
+			brasero_burn_session_set_fake_drive (self);
 
 		return BRASERO_BURN_OK;
 	}
 
-	if (!BRASERO_BURN_SESSION_WRITE_TO_FILE (priv)) {
-		BraseroMediumMonitor *monitor;
-		BraseroDrive *drive;
-		GSList *list;
-
-		brasero_burn_session_set_image_output_real (self, format, image, toc);
-
-		monitor = brasero_medium_monitor_get_default ();
-		list = brasero_medium_monitor_get_media (monitor, BRASERO_MEDIA_TYPE_FILE);
-		drive = brasero_medium_get_drive (list->data);
-		brasero_burn_session_set_burner (self, drive);
-		g_object_unref (monitor);
-		g_slist_free (list);
-	}
-	else {
-		brasero_burn_session_set_image_output_real (self, format, image, toc);
+	brasero_burn_session_set_image_output_real (self, format, image, toc);
+	if (BRASERO_BURN_SESSION_WRITE_TO_FILE (priv))
 		g_signal_emit (self,
 			       brasero_burn_session_signals [OUTPUT_CHANGED_SIGNAL],
 			       0,
 			       brasero_drive_get_medium (priv->settings->burner));
-	}
+	else
+		brasero_burn_session_set_fake_drive (self);
 
 	return BRASERO_BURN_OK;
 }
@@ -1004,6 +1045,8 @@ brasero_burn_session_set_output_image_real (BraseroBurnSession *self,
  * NOTE: after a call to this function the #BraseroDrive for
  * @session will be the fake #BraseroDrive.
  *
+ * Since 2.29.0
+ *
  * Return value: a #BraseroBurnResult. BRASERO_BURN_OK if it was successfully set;
  * BRASERO_BURN_ERR otherwise.
  **/
@@ -1280,7 +1323,7 @@ brasero_burn_session_get_image_complement (BraseroBurnSession *self,
 	else if (format == BRASERO_IMAGE_FORMAT_CUE) {
 		if (g_str_has_suffix (path, ".bin"))
 			retval = g_strdup_printf ("%.*scue",
-						  strlen (path) - 3,
+						  (int) strlen (path) - 3,
 						  path);
 		else
 			retval = g_strdup_printf ("%s.cue", path);
@@ -1288,7 +1331,7 @@ brasero_burn_session_get_image_complement (BraseroBurnSession *self,
 	else if (format == BRASERO_IMAGE_FORMAT_CDRDAO) {
 		if (g_str_has_suffix (path, ".bin"))
 			retval = g_strdup_printf ("%.*stoc",
-						  strlen (path) - 3,
+						  (int) strlen (path) - 3,
 						  path);
 		else
 			retval = g_strdup_printf ("%s.toc", path);
@@ -1628,6 +1671,8 @@ brasero_burn_session_tag_add (BraseroBurnSession *self,
  * for video discs, ...
  * See brasero-tags.h for a list of knowns tags.
  *
+ * Since 2.29.0
+ *
  * Return value: a #BraseroBurnResult.
  * BRASERO_BURN_OK if it was successful,
  * BRASERO_BURN_ERR otherwise.
@@ -1702,6 +1747,8 @@ brasero_burn_session_tag_lookup (BraseroBurnSession *self,
  * Retrieves an int value associated with @session through
  * brasero_session_tag_add () and returns it.
  *
+ * Since 2.29.0
+ *
  * Return value: a #gint.
  **/
 
@@ -2049,7 +2096,8 @@ brasero_burn_session_logv (BraseroBurnSession *self,
 
 	g_free (message);
 
-	fwrite ("\n", 1, 1, priv->session);
+	if (fwrite ("\n", 1, 1, priv->session) != 1)
+		g_warning ("Some log data could not be written");
 }
 
 void
