@@ -85,9 +85,9 @@ struct _BraseroBurnSessionClass {
 							 BraseroMedium *former_medium);
 };
 
-GType brasero_burn_session_get_type ();
+GType brasero_burn_session_get_type (void);
 
-BraseroBurnSession *brasero_burn_session_new ();
+BraseroBurnSession *brasero_burn_session_new (void);
 
 
 /**
@@ -146,9 +146,20 @@ BraseroBurnResult
 brasero_burn_session_tag_remove (BraseroBurnSession *session,
 				 const gchar *tag);
 
+BraseroBurnResult
+brasero_burn_session_tag_add_int (BraseroBurnSession *self,
+                                  const gchar *tag,
+                                  gint value);
+gint
+brasero_burn_session_tag_lookup_int (BraseroBurnSession *self,
+                                     const gchar *tag);
+
 /**
  * Destination 
  */
+BraseroBurnResult
+brasero_burn_session_get_output_type (BraseroBurnSession *self,
+                                      BraseroTrackType *output);
 
 BraseroDrive *
 brasero_burn_session_get_burner (BraseroBurnSession *session);
@@ -168,10 +179,13 @@ brasero_burn_session_get_output (BraseroBurnSession *session,
 				 gchar **image,
 				 gchar **toc);
 
+BraseroBurnResult
+brasero_burn_session_set_image_output_format (BraseroBurnSession *self,
+					    BraseroImageFormat format);
+
 BraseroImageFormat
 brasero_burn_session_get_output_format (BraseroBurnSession *session);
 
-
 const gchar *
 brasero_burn_session_get_label (BraseroBurnSession *session);
 
