@@ -619,7 +619,7 @@ brasero_track_data_cfg_get_value (GtkTreeModel *model,
 		case BRASERO_DATA_TREE_MODEL_NAME:
 			g_value_init (value, G_TYPE_STRING);
 			if (node->is_exploring)
-				g_value_set_string (value, _("(loading ...)"));
+				g_value_set_string (value, _("(loading…)"));
 			else
 				g_value_set_string (value, _("Empty"));
 
@@ -718,7 +718,7 @@ brasero_track_data_cfg_get_value (GtkTreeModel *model,
 	case BRASERO_DATA_TREE_MODEL_MIME_DESC:
 		g_value_init (value, G_TYPE_STRING);
 		if (node->is_loading)
-			g_value_set_string (value, _("(loading ...)"));
+			g_value_set_string (value, _("(loading…)"));
 		else if (!node->is_file) {
 			gchar *description;
 
@@ -729,7 +729,7 @@ brasero_track_data_cfg_get_value (GtkTreeModel *model,
 		else if (node->is_imported)
 			g_value_set_string (value, _("Disc file"));
 		else if (!BRASERO_FILE_NODE_MIME (node))
-			g_value_set_string (value, _("(loading ...)"));
+			g_value_set_string (value, _("(loading…)"));
 		else {
 			gchar *description;
 
@@ -790,12 +790,12 @@ brasero_track_data_cfg_get_value (GtkTreeModel *model,
 	case BRASERO_DATA_TREE_MODEL_SIZE:
 		g_value_init (value, G_TYPE_STRING);
 		if (node->is_loading)
-			g_value_set_string (value, _("(loading ...)"));
+			g_value_set_string (value, _("(loading…)"));
 		else if (!node->is_file) {
 			guint nb_items;
 
 			if (node->is_exploring) {
-				g_value_set_string (value, _("(loading ...)"));
+				g_value_set_string (value, _("(loading…)"));
 				return;
 			}
 
@@ -1179,13 +1179,6 @@ brasero_track_data_cfg_drag_data_received (GtkTreeDragDest *drag_dest,
 		 * success is enough to return TRUE. */
 		success = FALSE;
 		uris = gtk_selection_data_get_uris (selection_data);
-		if (!uris) {
-			const guchar *selection_data_raw;
-
-			selection_data_raw = gtk_selection_data_get_data (selection_data);
-			uris = g_uri_list_extract_uris ((gchar *) selection_data_raw);
-		}
-
 		if (!uris)
 			return TRUE;
 
