@@ -39,12 +39,12 @@
 
 #include "brasero-misc.h"
 
+#include "burn-debug.h"
+
 #include "brasero-track-stream-cfg.h"
 #include "brasero-io.h"
 #include "brasero-tags.h"
 
-static BraseroIOJobCallbacks *io_methods = NULL;
-
 typedef struct _BraseroTrackStreamCfgPrivate BraseroTrackStreamCfgPrivate;
 struct _BraseroTrackStreamCfgPrivate
 {
@@ -104,8 +104,8 @@ brasero_track_stream_cfg_results_cb (GObject *obj,
 				     GFileInfo *info,
 				     gpointer user_data)
 {
-	guint64 len;
 	GFile *file;
+	guint64 len;
 	GObject *snapshot;
 	BraseroTrackStreamCfgPrivate *priv;
 
@@ -187,13 +187,20 @@ brasero_track_stream_cfg_results_cb (GObject *obj,
 		g_free (sym_uri);
 	}
 
-	if (BRASERO_TRACK_STREAM_CLASS (brasero_track_stream_cfg_parent_class)->set_format)
+	/* Check whether the stream is wav+dts as it can be burnt as such */
+	if (g_file_info_get_attribute_boolean (info, BRASERO_IO_HAS_DTS)) {
+		BRASERO_BURN_LOG ("Track has DTS");
+		BRASERO_TRACK_STREAM_CLASS (brasero_track_stream_cfg_parent_class)->set_format (BRASERO_TRACK_STREAM (obj), 
+		                                                                                BRASERO_AUDIO_FORMAT_DTS|
+		                                                                                BRASERO_METADATA_INFO);
+	}
+	else if (BRASERO_TRACK_STREAM_CLASS (brasero_track_stream_cfg_parent_class)->set_format)
 		BRASERO_TRACK_STREAM_CLASS (brasero_track_stream_cfg_parent_class)->set_format (BRASERO_TRACK_STREAM (obj),
-												(g_file_info_get_attribute_boolean (info, BRASERO_IO_HAS_VIDEO)?
-												 BRASERO_VIDEO_FORMAT_UNDEFINED:BRASERO_AUDIO_FORMAT_NONE)|
-												(g_file_info_get_attribute_boolean (info, BRASERO_IO_HAS_AUDIO)?
-												 BRASERO_AUDIO_FORMAT_UNDEFINED:BRASERO_AUDIO_FORMAT_NONE)|
-												BRASERO_METADATA_INFO);
+		                                                                                (g_file_info_get_attribute_boolean (info, BRASERO_IO_HAS_VIDEO)?
+		                                                                                 BRASERO_VIDEO_FORMAT_UNDEFINED:BRASERO_AUDIO_FORMAT_NONE)|
+		                                                                                (g_file_info_get_attribute_boolean (info, BRASERO_IO_HAS_AUDIO)?
+		                                                                                 BRASERO_AUDIO_FORMAT_UNDEFINED:BRASERO_AUDIO_FORMAT_NONE)|
+		                                                                                BRASERO_METADATA_INFO);
 
 	/* size */
 	if (BRASERO_TRACK_STREAM_CLASS (brasero_track_stream_cfg_parent_class)->set_boundaries)
@@ -297,14 +304,11 @@ brasero_track_stream_cfg_get_info (BraseroTrackStreamCfg *track)
 	}
 
 	/* get info async for the file */
-	if (!priv->load_uri) {
-		if (!io_methods)
-			io_methods = brasero_io_register_job_methods (brasero_track_stream_cfg_results_cb,
-			                                              NULL,
-			                                              NULL);
-
-		priv->load_uri = brasero_io_register_with_methods (G_OBJECT (track), io_methods);
-	}
+	if (!priv->load_uri)
+		priv->load_uri = brasero_io_register (G_OBJECT (track),
+						      brasero_track_stream_cfg_results_cb,
+						      NULL,
+						      NULL);
 
 	priv->loading = TRUE;
 	uri = brasero_track_stream_get_source (BRASERO_TRACK_STREAM (track), TRUE);
@@ -384,11 +388,7 @@ brasero_track_stream_cfg_finalize (GObject *object)
 
 	if (priv->load_uri) {
 		brasero_io_cancel_by_base (priv->load_uri);
-
-		if (io_methods->ref == 1)
-			io_methods = NULL;
-
-		brasero_io_job_base_free (priv->load_uri);
+		g_free (priv->load_uri);
 		priv->load_uri = NULL;
 	}
 
