@@ -282,7 +282,7 @@ brasero_drive_eject (BraseroDrive *drive,
 
 	BRASERO_MEDIA_LOG ("Trying to eject drive");
 	if (priv->gdrive) {
-		/*Wait for any ongoing probing as it
+		/* Wait for any ongoing probing as it
 		 * would prevent the door from being
 		 * opened. */
 		brasero_drive_wait_probing_thread (drive);
@@ -314,9 +314,10 @@ brasero_drive_eject (BraseroDrive *drive,
 		g_cancellable_reset (priv->cancel);
 	}
 
-	BRASERO_MEDIA_LOG ("Trying to eject volume");
 	gvolume = brasero_volume_get_gvolume (BRASERO_VOLUME (priv->medium));
 	if (gvolume) {
+		BRASERO_MEDIA_LOG ("Trying to eject volume");
+
 		/* Cancel any ongoing probing as it
 		 * would prevent the door from being
 		 * opened. */
@@ -573,9 +574,6 @@ brasero_drive_unlock (BraseroDrive *drive)
 			BRASERO_MEDIA_LOG ("Probe on hold");
 
 			/* A probe was waiting */
-			priv->probe_waiting = FALSE;
-
-			BRASERO_MEDIA_LOG ("Probe on hold");
 			brasero_drive_probe_inside (drive);
 		}
 	}
@@ -750,6 +748,8 @@ brasero_drive_get_caps (BraseroDrive *drive)
  *
  * Returns whether the disc can burn a specific media type.
  *
+ * Since 2.29.0
+ *
  * Return value: a #gboolean. TRUE if the drive can write this type of media and FALSE otherwise
  **/
 gboolean
@@ -862,7 +862,7 @@ brasero_drive_medium_probed (BraseroMedium *medium,
 }
 
 /**
- * This is not public API. Defined in burn-monitor.h.
+ * This is not public API. Defined in brasero-drive-priv.h.
  */
 gboolean
 brasero_drive_probing (BraseroDrive *drive)
