@@ -33,6 +33,7 @@
 #endif
 
 #include <string.h>
+#include <stdio.h>
 
 #include <glib.h>
 #include <glib/gi18n-lib.h>
@@ -55,6 +56,12 @@ static const GOptionEntry options [] = {
 	{ NULL }
 };
 
+void
+brasero_media_library_set_debug (gboolean value)
+{
+	debug = value;
+}
+
 static GSList *
 brasero_media_add_to_list (GSList *retval,
 			   BraseroMedia media)
@@ -452,8 +459,6 @@ brasero_media_to_string (BraseroMedia media,
 		strcat (buffer, "Unformatted ");
 }
 
-#define BRASERO_MEDIA_LOG_DOMAIN				"BraseroMedia"
-
 /**
  * brasero_media_get_option_group:
  *
@@ -470,7 +475,7 @@ brasero_media_get_option_group (void)
 
 	group = g_option_group_new ("brasero-media",
 				    N_("Brasero optical media library"),
-				    N_("Display options for Brasero-media library"),
+				    N_("Display options for Brasero media library"),
 				    NULL,
 				    NULL);
 	g_option_group_add_entries (group, options);
@@ -488,15 +493,12 @@ brasero_media_message (const gchar *location,
 	if (!debug)
 		return;
 
-	format_real = g_strdup_printf ("At %s: %s",
+	format_real = g_strdup_printf ("BraseroMedia: (at %s) %s\n",
 				       location,
 				       format);
 
 	va_start (arg_list, format);
-	g_logv (BRASERO_MEDIA_LOG_DOMAIN,
-		G_LOG_LEVEL_DEBUG,
-		format_real,
-		arg_list);
+	vprintf (format_real, arg_list);
 	va_end (arg_list);
 
 	g_free (format_real);
@@ -524,6 +526,25 @@ brasero_media_library_start (void)
 		return;
 	}
 
+	BRASERO_MEDIA_LOG ("Initializing Brasero-media %i.%i.%i",
+	                    BRASERO_MAJOR_VERSION,
+	                    BRASERO_MINOR_VERSION,
+	                    BRASERO_SUB);
+
+#if defined(HAVE_STRUCT_USCSI_CMD)
+	/* Work around: because on OpenSolaris brasero posiblely be run
+	 * as root for a user with 'Primary Administrator' profile,
+	 * a root dbus session will be autospawned at that time.
+	 * This fix is to work around
+	 * http://bugzilla.gnome.org/show_bug.cgi?id=526454
+	 */
+	g_setenv ("DBUS_SESSION_BUS_ADDRESS", "autolaunch:", TRUE);
+#endif
+
+	/* Initialize external libraries (threads... */
+	if (!g_thread_supported ())
+		g_thread_init (NULL);
+
 	/* Initialize i18n */
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
