@@ -182,9 +182,9 @@ brasero_io_job_progress_report_cb (gpointer callback_data)
 
 		/* update our progress */
 		progress->progress (progress->job, progress);
-		progress->job->base->methods->progress (progress->job->base->object,
-		                                        progress,
-		                                        callback_data);
+		progress->job->base->progress (progress->job->base->object,
+					       progress,
+					       callback_data);
 	}
 	g_mutex_unlock (priv->lock);
 
@@ -201,7 +201,7 @@ brasero_io_job_progress_report_start (BraseroIO *self,
 
 	priv = BRASERO_IO_PRIVATE (self);
 
-	if (!job->base->methods->progress)
+	if (!job->base->progress)
 		return;
 
 	progress = g_new0 (BraseroIOJobProgress, 1);
@@ -248,12 +248,6 @@ brasero_io_job_progress_report_stop (BraseroIO *self,
 	g_mutex_unlock (priv->lock);
 }
 
-const gchar *
-brasero_io_job_progress_get_current (BraseroIOJobProgress *progress)
-{
-	return g_strdup (progress->current);
-}
-
 guint
 brasero_io_job_progress_get_file_processed (BraseroIOJobProgress *progress)
 {
@@ -327,6 +321,8 @@ brasero_io_return_result_idle (gpointer callback_data)
 	BraseroIOJobResult *result;
 	BraseroIOPrivate *priv;
 	guint results_id;
+	GSList *iter;
+	GSList *next;
 	int i;
 
 	priv = BRASERO_IO_PRIVATE (self);
@@ -335,72 +331,62 @@ brasero_io_return_result_idle (gpointer callback_data)
 
 	/* Put that to 0 for now so that a new idle call will be scheduled while
 	 * we are in the loop. That way if we block the other one will be able 
-	 * to deliver results. */
+	 * to deliver the results. */
 	results_id = priv->results_id;
 	priv->results_id = 0;
 
 	/* Return several results at a time that can be a huge speed gain.
 	 * What should be the value that provides speed and responsiveness? */
-	for (i = 0; priv->results && i < NUMBER_OF_RESULTS;) {
+	for (i = 0, iter = priv->results; iter && i < NUMBER_OF_RESULTS; iter = next) {
 		BraseroIOJobBase *base;
-		GSList *iter;
 
-		/* Find the next result that can be returned */
-		result = NULL;
-		for (iter = priv->results; iter; iter = iter->next) {
-			BraseroIOJobResult *tmp_result;
-
-			tmp_result = iter->data;
-			if (!tmp_result->base->methods->in_use) {
-				result = tmp_result;
-				break;
-			}
-		}
-
-		if (!result)
-			break;
+		result = iter->data;
+		next = iter->next;
 
 		/* Make sure another result is not returned for this base. This 
 		 * is to avoid BraseroDataDisc showing multiple dialogs for 
 		 * various problems; like one dialog for joliet, one for deep,
 		 * and one for name collision. */
-		base = (BraseroIOJobBase *) result->base;
-		base->methods->in_use = TRUE;
+		if (result->base->in_use)
+			continue;
 
 		priv->results = g_slist_remove (priv->results, result);
 
-		/* This is to make sure the object
-		 *  lives as long as we need it. */
-		g_object_ref (base->object);
+		base = (BraseroIOJobBase *) result->base;
+		base->in_use = TRUE;
 
 		g_mutex_unlock (priv->lock);
 
 		data = result->callback_data;
 
+		/* This is to make sure the object lives
+		 * as long as we need it. */
+		g_object_ref (base->object);
+
 		if (result->uri || result->info || result->error)
-			base->methods->callback (base->object,
-			                          result->error,
-			                          result->uri,
-			                          result->info,
-			                          data? data->callback_data:NULL);
+			result->base->callback (base->object,
+						result->error,
+						result->uri,
+						result->info,
+						data? data->callback_data:NULL);
 
 		/* call destroy () for callback data */
 		brasero_io_unref_result_callback_data (data,
 						       base->object,
-						       base->methods->destroy,
+						       base->destroy,
 						       FALSE);
 
+		g_object_unref (base->object);
+
 		brasero_io_job_result_free (result);
 
 		g_mutex_lock (priv->lock);
 
 		i ++;
-
-		g_object_unref (base->object);
-		base->methods->in_use = FALSE;
+		base->in_use = FALSE;
 	}
 
-	if (!priv->results_id && priv->results && i >= NUMBER_OF_RESULTS) {
+	if (!priv->results_id && iter && i >= NUMBER_OF_RESULTS) {
 		/* There are still results and no idle call is scheduled so we
 		 * have to restart ourselves to make sure we empty the queue */
 		priv->results_id = results_id;
@@ -528,10 +514,10 @@ brasero_io_job_free (gboolean cancelled,
 		 * add a dummy result to destroy callback_data. */
 		if (g_atomic_int_dec_and_test (&job->callback_data->ref)) {
 			if (cancelled) {
-				if (job->base->methods->destroy)
-					job->base->methods->destroy (job->base->object,
-					                              TRUE,
-					                              job->callback_data->callback_data);
+				if (job->base->destroy)
+					job->base->destroy (job->base->object,
+							    TRUE,
+							    job->callback_data->callback_data);
 
 				g_free (job->callback_data);
 			}
@@ -802,8 +788,6 @@ typedef struct _BraseroIOMetadataTask BraseroIOMetadataTask;
 struct _BraseroIOMetadataCached {
 	guint64 last_modified;
 	BraseroMetadataInfo *info;
-
-	guint missing_codec_used:1;
 };
 typedef struct _BraseroIOMetadataCached BraseroIOMetadataCached;
 
@@ -849,8 +833,20 @@ brasero_io_set_metadata_attributes (GFileInfo *info,
 		g_file_info_set_attribute_string (info, BRASERO_IO_COMPOSER, metadata->composer);
 
 	g_file_info_set_attribute_boolean (info, BRASERO_IO_HAS_AUDIO, metadata->has_audio);
+	if (metadata->has_audio) {
+		if (metadata->channels)
+			g_file_info_set_attribute_int32 (info, BRASERO_IO_CHANNELS, metadata->channels);
+
+		if (metadata->rate)
+			g_file_info_set_attribute_int32 (info, BRASERO_IO_RATE, metadata->rate);
+
+		if (metadata->has_dts)
+			g_file_info_set_attribute_boolean (info, BRASERO_IO_HAS_DTS, TRUE);
+	}
+
 	g_file_info_set_attribute_boolean (info, BRASERO_IO_HAS_VIDEO, metadata->has_video);
 	g_file_info_set_attribute_boolean (info, BRASERO_IO_IS_SEEKABLE, metadata->is_seekable);
+
 	if (metadata->snapshot)
 		g_file_info_set_attribute_object (info, BRASERO_IO_THUMBNAIL, G_OBJECT (metadata->snapshot));
 
@@ -935,7 +931,6 @@ brasero_io_wait_for_metadata (BraseroIO *self,
 			      GCancellable *cancel,
 			      GFileInfo *info,
 			      BraseroMetadata *metadata,
-			      BraseroMetadataFlag flags,
 			      BraseroMetadataInfo *meta_info)
 {
 	gboolean result;
@@ -972,8 +967,6 @@ brasero_io_wait_for_metadata (BraseroIO *self,
 			cached->info = g_new0 (BraseroMetadataInfo, 1);
 			brasero_metadata_get_result (metadata, cached->info, NULL);
 
-			cached->missing_codec_used = (flags & BRASERO_METADATA_FLAG_MISSING) != 0;
-
 			g_queue_push_head (priv->meta_buffer, cached);
 			if (g_queue_get_length (priv->meta_buffer) > MAX_BUFFERED_META) {
 				cached = g_queue_pop_tail (priv->meta_buffer);
@@ -1037,24 +1030,15 @@ brasero_io_get_metadata_info (BraseroIO *self,
 		cached = node->data;
 		last_modified = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_STANDARD_SIZE);
 		if (last_modified == cached->last_modified) {
-			gboolean refresh_cache = FALSE;
-
-			if (flags & BRASERO_METADATA_FLAG_MISSING) {
-				/* This cached result may indicate an error and
-				 * this error could be related to the fact that
-				 * it was not first looked for with missing
-				 * codec detection. */
-				if (!cached->missing_codec_used)
-					refresh_cache = TRUE;
-			}
-
 			if (flags & BRASERO_METADATA_FLAG_THUMBNAIL) {
 				/* If there isn't any snapshot retry */
-				if (!cached->info->snapshot)
-					refresh_cache = TRUE;
+				if (cached->info->snapshot) {
+					brasero_metadata_info_copy (meta_info, cached->info);
+					g_mutex_unlock (priv->lock_metadata);
+					return TRUE;
+				}
 			}
-
-			if (!refresh_cache) {
+			else {
 				brasero_metadata_info_copy (meta_info, cached->info);
 				g_mutex_unlock (priv->lock_metadata);
 				return TRUE;
@@ -1081,7 +1065,6 @@ brasero_io_get_metadata_info (BraseroIO *self,
 					     cancel,
 					     info,
 					     metadata,
-					     flags,
 					     meta_info);
 }
 
@@ -1633,8 +1616,8 @@ brasero_io_get_file_count_process_file (BraseroIO *self,
 				if (!brasero_io_get_file_count_process_playlist (self, cancel, data, child_uri))
 					data->files_invalid ++;
 			}
-			else
-				data->files_invalid ++;
+
+			data->files_invalid ++;
 		}
 
 #endif
@@ -1740,8 +1723,8 @@ brasero_io_get_file_count_start (BraseroIO *self,
 				  (data->job.options & BRASERO_IO_INFO_FOLLOW_SYMLINK)?G_FILE_QUERY_INFO_NONE:G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,	/* follow symlinks by default*/
 				  cancel,
 				  NULL);
-	data->files_num ++;
 
+	data->files_num ++;
 	if (!info) {
 		g_object_unref (file);
 		data->files_invalid ++;
@@ -1791,8 +1774,7 @@ brasero_io_get_file_count_thread (BraseroAsyncTaskManager *manager,
 		brasero_io_get_file_count_process_directory (BRASERO_IO (manager), cancel, data);
 		return BRASERO_ASYNC_TASK_RESCHEDULE;
 	}
-
-	if (!data->uris) {
+	else if (!data->uris) {
 		info = g_file_info_new ();
 
 		/* set GFileInfo information */
@@ -2174,7 +2156,7 @@ brasero_io_cancel_result (BraseroIO *self,
 	data = result->callback_data;
 	brasero_io_unref_result_callback_data (data,
 					       result->base->object,
-					       result->base->methods->destroy,
+					       result->base->destroy,
 					       TRUE);
 	brasero_io_job_result_free (result);
 }
@@ -2317,58 +2299,21 @@ brasero_io_find_urgent (const BraseroIOJobBase *base,
 						     
 }
 
-BraseroIOJobCallbacks *
-brasero_io_register_job_methods (BraseroIOResultCallback callback,
-                                 BraseroIODestroyCallback destroy,
-                                 BraseroIOProgressCallback progress)
-{
-	BraseroIOJobCallbacks *methods;
-
-	methods = g_new0 (BraseroIOJobCallbacks, 1);
-	methods->callback = callback;
-	methods->destroy = destroy;
-	methods->progress = progress;
-
-	return methods;
-}
-
-BraseroIOJobBase *
-brasero_io_register_with_methods (GObject *object,
-                                  BraseroIOJobCallbacks *methods)
-{
-	BraseroIOJobBase *base;
-
-	base = g_new0 (BraseroIOJobBase, 1);
-	base->object = object;
-	base->methods = methods;
-	methods->ref ++;
-
-	return base;
-}
-
 BraseroIOJobBase *
 brasero_io_register (GObject *object,
 		     BraseroIOResultCallback callback,
 		     BraseroIODestroyCallback destroy,
 		     BraseroIOProgressCallback progress)
 {
-	return brasero_io_register_with_methods (object, brasero_io_register_job_methods (callback, destroy, progress));
-}
+	BraseroIOJobBase *base;
 
-void
-brasero_io_job_base_free (BraseroIOJobBase *base)
-{
-	BraseroIOJobCallbacks *methods;
+	base = g_new0 (BraseroIOJobBase, 1);
+	base->object = object;
+	base->callback = callback;
+	base->destroy = destroy;
+	base->progress = progress;
 
-	if (!base)
-		return;
-
-	methods = base->methods;
-	g_free (base);
-
-	methods->ref --;
-	if (methods->ref <= 0)
-		g_free (methods);
+	return base;
 }
 
 static void
