@@ -84,6 +84,11 @@ typedef enum {
 #define BRASERO_IO_HAS_VIDEO		"metadata::has_video"
 #define BRASERO_IO_IS_SEEKABLE		"metadata::is_seekable"
 
+#define BRASERO_IO_HAS_DTS			"metadata::audio::wav::has_dts"
+
+#define BRASERO_IO_CHANNELS		"metadata::audio::channels"
+#define BRASERO_IO_RATE				"metadata::audio::rate"
+
 #define BRASERO_IO_DIR_CONTENTS_ADDR	"image::directory::address"
 
 typedef struct _BraseroIOJobProgress BraseroIOJobProgress;
@@ -106,22 +111,15 @@ typedef gboolean	(*BraseroIOCompareCallback)	(gpointer data,
 							 gpointer user_data);
 
 
-struct _BraseroIOJobCallbacks {
+struct _BraseroIOJobBase {
+	GObject *object;
 	BraseroIOResultCallback callback;
 	BraseroIODestroyCallback destroy;
 	BraseroIOProgressCallback progress;
 
-	guint ref;
-
 	/* Whether we are returning something for this base */
 	guint in_use:1;
 };
-typedef struct _BraseroIOJobCallbacks BraseroIOJobCallbacks;
-
-struct _BraseroIOJobBase {
-	GObject *object;
-	BraseroIOJobCallbacks *methods;
-};
 typedef struct _BraseroIOJobBase BraseroIOJobBase;
 
 struct _BraseroIOResultCallbackData {
@@ -166,30 +164,12 @@ brasero_io_return_result (const BraseroIOJobBase *base,
 void
 brasero_io_shutdown (void);
 
-/* NOTE: The split in methods and objects was
- * done to prevent jobs sharing the same methods
- * to return their results concurently. In other
- * words only one job among those sharing the
- * same methods can return its results. */
- 
 BraseroIOJobBase *
 brasero_io_register (GObject *object,
 		     BraseroIOResultCallback callback,
 		     BraseroIODestroyCallback destroy,
 		     BraseroIOProgressCallback progress);
 
-BraseroIOJobBase *
-brasero_io_register_with_methods (GObject *object,
-                                  BraseroIOJobCallbacks *methods);
-
-BraseroIOJobCallbacks *
-brasero_io_register_job_methods (BraseroIOResultCallback callback,
-                                 BraseroIODestroyCallback destroy,
-                                 BraseroIOProgressCallback progress);
-
-void
-brasero_io_job_base_free (BraseroIOJobBase *base);
-
 void
 brasero_io_cancel_by_data (gpointer callback_data);
 
