@@ -46,7 +46,6 @@
 #include <gconf/gconf-client.h>
 
 #include "burn-cdrdao-common.h"
-#include "burn-cdrdao.h"
 #include "brasero-error.h"
 #include "brasero-plugin-registration.h"
 #include "burn-job.h"
@@ -56,6 +55,14 @@
 #include "brasero-drive.h"
 #include "brasero-medium.h"
 
+
+#define BRASERO_TYPE_CDRDAO         (brasero_cdrdao_get_type ())
+#define BRASERO_CDRDAO(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_CDRDAO, BraseroCdrdao))
+#define BRASERO_CDRDAO_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), BRASERO_TYPE_CDRDAO, BraseroCdrdaoClass))
+#define BRASERO_IS_CDRDAO(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), BRASERO_TYPE_CDRDAO))
+#define BRASERO_IS_CDRDAO_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), BRASERO_TYPE_CDRDAO))
+#define BRASERO_CDRDAO_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), BRASERO_TYPE_CDRDAO, BraseroCdrdaoClass))
+
 BRASERO_PLUGIN_BOILERPLATE (BraseroCdrdao, brasero_cdrdao, BRASERO_TYPE_PROCESS, BraseroProcess);
 
 struct _BraseroCdrdaoPrivate {
@@ -189,7 +196,8 @@ brasero_cdrdao_read_stderr_record (BraseroCdrdao *cdrdao, const gchar *line)
 		if (!cuepath)
 			return FALSE;
 
-		if (!strstr (line, "ERROR: Could not find input file")) {
+		if (!strstr (line, cuepath)
+		&&  !strstr (line, "ERROR: Could not find input file")) {
 			g_free (cuepath);
 			return FALSE;
 		}
@@ -206,7 +214,7 @@ brasero_cdrdao_read_stderr_record (BraseroCdrdao *cdrdao, const gchar *line)
 		g_free (name);
 	}
 
-	return FALSE;
+	return TRUE;
 }
 
 static BraseroBurnResult
@@ -685,7 +693,7 @@ brasero_cdrdao_export_caps (BraseroPlugin *plugin, gchar **error)
 					BRASERO_BURN_FLAG_NONE);
 
 	use_raw = brasero_plugin_conf_option_new (GCONF_KEY_RAW_FLAG,
-						  _("Enable \"--driver generic-mmc-raw\" flag (see cdrdao manual)"),
+						  _("Enable the \"--driver generic-mmc-raw\" flag (see cdrdao manual)"),
 						  BRASERO_PLUGIN_OPTION_BOOL);
 
 	brasero_plugin_add_conf_option (plugin, use_raw);
