@@ -46,9 +46,16 @@
 #include "burn-job.h"
 #include "burn-process.h"
 #include "burn-cdrdao-common.h"
-#include "burn-toc2cue.h"
 #include "brasero-track-image.h"
- 
+
+
+#define BRASERO_TYPE_TOC2CUE         (brasero_toc2cue_get_type ())
+#define BRASERO_TOC2CUE(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_TOC2CUE, BraseroToc2Cue))
+#define BRASERO_TOC2CUE_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), BRASERO_TYPE_TOC2CUE, BraseroToc2CueClass))
+#define BRASERO_IS_TOC2CUE(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), BRASERO_TYPE_TOC2CUE))
+#define BRASERO_IS_TOC2CUE_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), BRASERO_TYPE_TOC2CUE))
+#define BRASERO_TOC2CUE_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), BRASERO_TYPE_TOC2CUE, BraseroToc2CueClass))
+
 BRASERO_PLUGIN_BOILERPLATE (BraseroToc2Cue, brasero_toc2cue, BRASERO_TYPE_PROCESS, BraseroProcess);
 
 struct _BraseroToc2CuePrivate {
@@ -139,7 +146,7 @@ brasero_toc2cue_read_stderr (BraseroProcess *process,
 
 			tmp = buffer;
 			buffer = g_strdup_printf ("%.*s%s%s",
-						  location - buffer,
+						  (int) (location - buffer),
 						  buffer,
 						  img_path,
 						  location + tmp_path_len);
@@ -322,7 +329,7 @@ brasero_toc2cue_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "toc2cue",
-			       _("Toc2cue converts .toc files into .cue files"),
+			       _("toc2cue converts .toc files into .cue files"),
 			       "Philippe Rouquier",
 			       0);
 
