@@ -48,9 +48,16 @@
 #include "burn-process.h"
 #include "brasero-plugin-registration.h"
 #include "burn-cdrkit.h"
-#include "burn-genisoimage.h"
 #include "brasero-track-data.h"
 
+
+#define BRASERO_TYPE_GENISOIMAGE         (brasero_genisoimage_get_type ())
+#define BRASERO_GENISOIMAGE(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_GENISOIMAGE, BraseroGenisoimage))
+#define BRASERO_GENISOIMAGE_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), BRASERO_TYPE_GENISOIMAGE, BraseroGenisoimageClass))
+#define BRASERO_IS_GENISOIMAGE(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), BRASERO_TYPE_GENISOIMAGE))
+#define BRASERO_IS_GENISOIMAGE_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), BRASERO_TYPE_GENISOIMAGE))
+#define BRASERO_GENISOIMAGE_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), BRASERO_TYPE_GENISOIMAGE, BraseroGenisoimageClass))
+
 BRASERO_PLUGIN_BOILERPLATE (BraseroGenisoimage, brasero_genisoimage, BRASERO_TYPE_PROCESS, BraseroProcess);
 
 struct _BraseroGenisoimagePrivate {
@@ -86,7 +93,7 @@ brasero_genisoimage_read_stdout (BraseroProcess *process, const gchar *line)
 	if (action == BRASERO_JOB_ACTION_SIZE)
 		return brasero_genisoimage_read_isosize (process, line);
 
-	return TRUE;
+	return BRASERO_BURN_OK;
 }
 
 static BraseroBurnResult
@@ -361,7 +368,7 @@ brasero_genisoimage_set_argv_image (BraseroGenisoimage *genisoimage,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			return BRASERO_BURN_ERR;
 		}
 
