@@ -1,24 +1,28 @@
-/***************************************************************************
- *            mkisofs.c
- *
- *  dim jan 22 15:20:57 2006
- *  Copyright  2006  Rouquier Philippe
- *  bonfire-app@wanadoo.fr
- ***************************************************************************/
-
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
- *  Brasero is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * Libbrasero-burn
+ * Copyright (C) Philippe Rouquier 2005-2009 <bonfire-app@wanadoo.fr>
  *
- *  Brasero is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * Libbrasero-burn is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to:
+ * The Libbrasero-burn authors hereby grant permission for non-GPL compatible
+ * GStreamer plugins to be used and distributed together with GStreamer
+ * and Libbrasero-burn. This permission is above and beyond the permissions granted
+ * by the GPL license by which Libbrasero-burn is covered. If you modify this code
+ * you may extend this exception to your version of the code, but you are not
+ * obligated to do so. If you do not wish to do so, delete this exception
+ * statement from your version.
+ * 
+ * Libbrasero-burn is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Library General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to:
  * 	The Free Software Foundation, Inc.,
  * 	51 Franklin Street, Fifth Floor
  * 	Boston, MA  02110-1301, USA.
@@ -45,9 +49,16 @@
 #include "burn-process.h"
 #include "brasero-plugin-registration.h"
 #include "burn-cdrtools.h"
-#include "burn-mkisofs.h"
 #include "brasero-track-data.h"
 
+
+#define BRASERO_TYPE_MKISOFS         (brasero_mkisofs_get_type ())
+#define BRASERO_MKISOFS(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_MKISOFS, BraseroMkisofs))
+#define BRASERO_MKISOFS_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), BRASERO_TYPE_MKISOFS, BraseroMkisofsClass))
+#define BRASERO_IS_MKISOFS(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), BRASERO_TYPE_MKISOFS))
+#define BRASERO_IS_MKISOFS_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), BRASERO_TYPE_MKISOFS))
+#define BRASERO_MKISOFS_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), BRASERO_TYPE_MKISOFS, BraseroMkisofsClass))
+
 BRASERO_PLUGIN_BOILERPLATE (BraseroMkisofs, brasero_mkisofs, BRASERO_TYPE_PROCESS, BraseroProcess);
 
 struct _BraseroMkisofsPrivate {
@@ -83,7 +94,7 @@ brasero_mkisofs_read_stdout (BraseroProcess *process, const gchar *line)
 	if (action == BRASERO_JOB_ACTION_SIZE)
 		return brasero_mkisofs_read_isosize (process, line);
 
-	return TRUE;
+	return BRASERO_BURN_OK;
 }
 
 static BraseroBurnResult
@@ -358,7 +369,7 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			return BRASERO_BURN_ERR;
 		}
 
@@ -374,13 +385,11 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 
 			g_ptr_array_add (argv, g_strdup ("-M"));
 
-#ifdef HAVE_CAM_LIB_H
-	/* FreeBSD like that better */
+			/* NOTE: that function returns either bus_target_lun or the device path
+			 * according to OSes. Basically it returns bus/target/lun only for FreeBSD
+			 * which is the only OS in need for that. For all others it returns the device
+			 * path. */
 			brasero_job_get_bus_target_lun (BRASERO_JOB (mkisofs), &device);
-#else
-			brasero_job_get_device (BRASERO_JOB (mkisofs), &device);
-#endif
-
 			g_ptr_array_add (argv, device);
 		}
 	}
@@ -523,7 +532,7 @@ brasero_mkisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "mkisofs",
-			       _("Use mkisofs to create image from a file selection"),
+			       _("Use mkisofs to create an image from a file selection"),
 			       "Philippe Rouquier",
 			       0);
 
