@@ -50,7 +50,6 @@
 #include "scsi-device.h"
 #include "brasero-plugin-registration.h"
 #include "burn-job.h"
-#include "burn-checksum-files.h"
 
 #include "brasero-tags.h"
 #include "brasero-track-data.h"
@@ -62,6 +61,14 @@
 
 #include "burn-volume-read.h"
 
+
+#define BRASERO_TYPE_CHECKSUM_FILES		(brasero_checksum_files_get_type ())
+#define BRASERO_CHECKSUM_FILES(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_CHECKSUM_FILES, BraseroChecksumFiles))
+#define BRASERO_CHECKSUM_FILES_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), BRASERO_TYPE_CHECKSUM_FILES, BraseroChecksumFilesClass))
+#define BRASERO_IS_CHECKSUM_FILES(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), BRASERO_TYPE_CHECKSUM_FILES))
+#define BRASERO_IS_CHECKSUM_FILES_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), BRASERO_TYPE_CHECKSUM_FILES))
+#define BRASERO_CHECKSUM_FILES_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), BRASERO_TYPE_CHECKSUM_FILES, BraseroChecksumFilesClass))
+
 BRASERO_PLUGIN_BOILERPLATE (BraseroChecksumFiles, brasero_checksum_files, BRASERO_TYPE_JOB, BraseroJob);
 
 struct _BraseroChecksumFilesPrivate {
@@ -814,11 +821,11 @@ brasero_checksum_files_check_files (BraseroChecksumFiles *self,
 	BraseroVolFile *file;
 	BraseroDrive *drive;
 	BraseroMedium *medium;
-	BraseroVolFileHandle *handle;
 	GChecksumType gchecksum_type;
 	GArray *wrong_checksums = NULL;
 	BraseroDeviceHandle *dev_handle;
 	BraseroChecksumFilesPrivate *priv;
+	BraseroVolFileHandle *handle = NULL;
 	BraseroBurnResult result = BRASERO_BURN_OK;
 
 	priv = BRASERO_CHECKSUM_FILES_PRIVATE (self);
@@ -1457,7 +1464,7 @@ brasero_checksum_files_export_caps (BraseroPlugin *plugin, gchar **error)
 				* which will be translated only when it needs
 				* displaying. */
 			       N_("File Checksum"),
-			       _("Allows to check file integrities on a disc"),
+			       _("Allow file integrities to be checked on a disc"),
 			       "Philippe Rouquier",
 			       0);
 
