@@ -51,13 +51,20 @@
 
 #include "brasero-plugin-registration.h"
 #include "burn-job.h"
-#include "burn-checksum-image.h"
 #include "burn-volume.h"
 #include "brasero-drive.h"
 #include "brasero-track-disc.h"
 #include "brasero-track-image.h"
 #include "brasero-tags.h"
 
+
+#define BRASERO_TYPE_CHECKSUM_IMAGE		(brasero_checksum_image_get_type ())
+#define BRASERO_CHECKSUM_IMAGE(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_CHECKSUM_IMAGE, BraseroChecksumImage))
+#define BRASERO_CHECKSUM_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), BRASERO_TYPE_CHECKSUM_IMAGE, BraseroChecksumImageClass))
+#define BRASERO_IS_CHECKSUM_IMAGE(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), BRASERO_TYPE_CHECKSUM_IMAGE))
+#define BRASERO_IS_CHECKSUM_IMAGE_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), BRASERO_TYPE_CHECKSUM_IMAGE))
+#define BRASERO_CHECKSUM_GET_CLASS(o)		(G_TYPE_INSTANCE_GET_CLASS ((o), BRASERO_TYPE_CHECKSUM_IMAGE, BraseroChecksumImageClass))
+
 BRASERO_PLUGIN_BOILERPLATE (BraseroChecksumImage, brasero_checksum_image, BRASERO_TYPE_JOB, BraseroJob);
 
 struct _BraseroChecksumImagePrivate {
@@ -283,7 +290,7 @@ brasero_checksum_image_checksum_file_input (BraseroChecksumImage *self,
 	}
 
 	BRASERO_JOB_LOG (self,
-			 "Starting checksuming file %s (size = %i)",
+			 "Starting checksuming file %s (size = %"G_GOFFSET_FORMAT")",
 			 path,
 			 priv->total);
 
@@ -419,9 +426,6 @@ brasero_checksum_get_checksum_type (void)
 	checksum_type = gconf_client_get_int (client, GCONF_KEY_CHECKSUM_TYPE, NULL);
 	g_object_unref (client);
 
-	if (!checksum_type)
-		checksum_type = BRASERO_CHECKSUM_MD5;
-
 	return checksum_type;
 }
 
@@ -436,16 +440,17 @@ brasero_checksum_image_image_and_checksum (BraseroChecksumImage *self,
 	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (self);
 
 	priv->checksum_type = brasero_checksum_get_checksum_type ();
-	if (priv->checksum_type == BRASERO_CHECKSUM_NONE)
-		checksum_type = G_CHECKSUM_MD5;
-	else if (priv->checksum_type & BRASERO_CHECKSUM_MD5)
+
+	if (priv->checksum_type & BRASERO_CHECKSUM_MD5)
 		checksum_type = G_CHECKSUM_MD5;
 	else if (priv->checksum_type & BRASERO_CHECKSUM_SHA1)
 		checksum_type = G_CHECKSUM_SHA1;
 	else if (priv->checksum_type & BRASERO_CHECKSUM_SHA256)
 		checksum_type = G_CHECKSUM_SHA256;
-	else
+	else {
 		checksum_type = G_CHECKSUM_MD5;
+		priv->checksum_type = BRASERO_CHECKSUM_MD5;
+	}
 
 	brasero_job_set_current_action (BRASERO_JOB (self),
 					BRASERO_BURN_ACTION_CHECKSUM,
@@ -700,12 +705,14 @@ brasero_checksum_image_clock_tick (BraseroJob *job)
 	BraseroChecksumImagePrivate *priv;
 
 	priv = BRASERO_CHECKSUM_IMAGE_PRIVATE (job);
+
 	if (!priv->checksum)
 		return BRASERO_BURN_OK;
 
 	if (!priv->total)
 		return BRASERO_BURN_OK;
 
+	brasero_job_start_progress (job, FALSE);
 	brasero_job_set_progress (job,
 				  (gdouble) priv->bytes /
 				  (gdouble) priv->total);
@@ -821,7 +828,7 @@ brasero_checksum_image_export_caps (BraseroPlugin *plugin, gchar **error)
 				* which will be translated only when it needs
 				* displaying. */
 			       N_("Image Checksum"),
-			       _("Allows to check data integrity on disc after it is burnt"),
+			       _("Allows data integrity to be checked on disc after it is burned"),
 			       "Philippe Rouquier",
 			       0);
 
