@@ -52,10 +52,17 @@
 #include "brasero-plugin-registration.h"
 #include "burn-libburn-common.h"
 #include "burn-libburnia.h"
-#include "burn-libburn.h"
 #include "brasero-track-image.h"
 #include "brasero-track-stream.h"
 
+
+#define BRASERO_TYPE_LIBBURN         (brasero_libburn_get_type ())
+#define BRASERO_LIBBURN(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_LIBBURN, BraseroLibburn))
+#define BRASERO_LIBBURN_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), BRASERO_TYPE_LIBBURN, BraseroLibburnClass))
+#define BRASERO_IS_LIBBURN(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), BRASERO_TYPE_LIBBURN))
+#define BRASERO_IS_LIBBURN_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), BRASERO_TYPE_LIBBURN))
+#define BRASERO_LIBBURN_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), BRASERO_TYPE_LIBBURN, BraseroLibburnClass))
+
 BRASERO_PLUGIN_BOILERPLATE (BraseroLibburn, brasero_libburn, BRASERO_TYPE_JOB, BraseroJob);
 
 #define BRASERO_PVD_SIZE	32ULL * 2048ULL
@@ -232,7 +239,7 @@ brasero_libburn_add_track (struct burn_session *session,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Libburn track could not be created"));
+			     _("libburn track could not be created"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -240,7 +247,7 @@ brasero_libburn_add_track (struct burn_session *session,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Libburn track could not be created"));
+			     _("libburn track could not be created"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -508,7 +515,12 @@ brasero_libburn_start_record (BraseroLibburn *self,
 	 * checking thing earlier ourselves. Now there is a proper
 	 * disc and tray is locked. */
 	opts = burn_write_opts_new (priv->ctx->drive);
-	burn_write_opts_set_perform_opc (opts, 0);
+
+	/* only turn this on for CDs */
+	if ((media & BRASERO_MEDIUM_CD) != 0)
+		burn_write_opts_set_perform_opc (opts, 0);
+	else
+		burn_write_opts_set_perform_opc (opts, 0);
 
 	if (flags & BRASERO_BURN_FLAG_DAO)
 		burn_write_opts_set_write_type (opts,
@@ -533,16 +545,22 @@ brasero_libburn_start_record (BraseroLibburn *self,
 		}
 	}
 
-	if (!BRASERO_MEDIUM_RANDOM_WRITABLE (media))
+	if (!BRASERO_MEDIUM_RANDOM_WRITABLE (media)) {
+		BRASERO_JOB_LOG (BRASERO_JOB (self), "Setting multi %i", (flags & BRASERO_BURN_FLAG_MULTI) != 0);
 		burn_write_opts_set_multi (opts, (flags & BRASERO_BURN_FLAG_MULTI) != 0);
+	}
 
 	burn_write_opts_set_underrun_proof (opts, (flags & BRASERO_BURN_FLAG_BURNPROOF) != 0);
+	BRASERO_JOB_LOG (BRASERO_JOB (self), "Setting burnproof %i", (flags & BRASERO_BURN_FLAG_BURNPROOF) != 0);
+
 	burn_write_opts_set_simulate (opts, (flags & BRASERO_BURN_FLAG_DUMMY) != 0);
+	BRASERO_JOB_LOG (BRASERO_JOB (self), "Setting dummy %i", (flags & BRASERO_BURN_FLAG_DUMMY) != 0);
 
 	brasero_job_get_rate (BRASERO_JOB (self), &rate);
 	burn_drive_set_speed (priv->ctx->drive, rate, 0);
 
 	if (burn_precheck_write (opts, priv->ctx->disc, reason, 0) < 1) {
+		BRASERO_JOB_LOG (BRASERO_JOB (self), "Precheck failed %s", reason);
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
@@ -635,6 +653,10 @@ brasero_libburn_start_erase (BraseroLibburn *self,
 			priv->sig_handler = 1;
 		}
 
+		/* NOTE: for an unknown reason (to me)
+		 * libburn when minimally blanking a DVD-RW
+		 * will only allow to write to it with DAO 
+		 * afterwards... */
 		burn_disc_erase (priv->ctx->drive, (flags & BRASERO_BURN_FLAG_FAST_BLANK) != 0);
 		return BRASERO_BURN_OK;
 	}
@@ -642,7 +664,8 @@ brasero_libburn_start_erase (BraseroLibburn *self,
 		BRASERO_JOB_NOT_SUPPORTED (self);
 
 	/* This is the "fast option": basically we only write 64 Kib of 0 from
-	 * /dev/null */
+	 * /dev/null. If we reached that part it means we're dealing with
+	 * overwrite media. */
 	fd = open ("/dev/null", O_RDONLY);
 	if (fd == -1) {
 		int errnum = errno;
@@ -690,7 +713,7 @@ brasero_libburn_start_erase (BraseroLibburn *self,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
 			     /* Translators: %s is the error returned by libburn */
-			     _("An internal error occured (%s)"),
+			     _("An internal error occurred (%s)"),
 			     reasons);
 		return BRASERO_BURN_ERR;
 	}
@@ -720,9 +743,25 @@ brasero_libburn_start (BraseroJob *job,
 
 	brasero_job_get_action (job, &action);
 	if (action == BRASERO_JOB_ACTION_RECORD) {
-		priv->ctx = brasero_libburn_common_ctx_new (job, error);
-		if (!priv->ctx)
+		GError *ret_error = NULL;
+
+		/* TRUE is a context that helps to adapt action
+		 * messages like for DVD+RW which need a
+		 * pre-formatting before actually writing
+		 * and without this we would not know if
+		 * we are actually formatting or just pre-
+		 * formatting == starting to record */
+		priv->ctx = brasero_libburn_common_ctx_new (job, TRUE, &ret_error);
+		if (!priv->ctx) {
+			if (ret_error && ret_error->code == BRASERO_BURN_ERROR_DRIVE_BUSY) {
+				g_propagate_error (error, ret_error);
+				return BRASERO_BURN_RETRY;
+			}
+
+			if (error)
+				g_propagate_error (error, ret_error);
 			return BRASERO_BURN_ERR;
+		}
 
 		result = brasero_libburn_start_record (self, error);
 		if (result != BRASERO_BURN_OK)
@@ -734,9 +773,19 @@ brasero_libburn_start (BraseroJob *job,
 						FALSE);
 	}
 	else if (action == BRASERO_JOB_ACTION_ERASE) {
-		priv->ctx = brasero_libburn_common_ctx_new (job, error);
-		if (!priv->ctx)
+		GError *ret_error = NULL;
+
+		priv->ctx = brasero_libburn_common_ctx_new (job, FALSE, &ret_error);
+		if (!priv->ctx) {
+			if (ret_error && ret_error->code == BRASERO_BURN_ERROR_DRIVE_BUSY) {
+				g_propagate_error (error, ret_error);
+				return BRASERO_BURN_RETRY;
+			}
+
+			if (error)
+				g_propagate_error (error, ret_error);
 			return BRASERO_BURN_ERR;
+		}
 
 		result = brasero_libburn_start_erase (self, error);
 		if (result != BRASERO_BURN_OK)
@@ -803,7 +852,7 @@ brasero_libburn_clock_tick (BraseroJob *job)
 		brasero_job_error (job,
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_WRITE_MEDIUM,
-						_("An error occured while writing to disc")));
+						_("An error occurred while writing to disc")));
 		return BRASERO_BURN_OK;
 	}
 
@@ -834,7 +883,7 @@ brasero_libburn_clock_tick (BraseroJob *job)
 		brasero_job_error (job,
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_WRITE_MEDIUM,
-						_("An error occured while writing to disc")));
+						_("An error occurred while writing to disc")));
 		return BRASERO_BURN_OK;
 	}
 
@@ -921,21 +970,32 @@ brasero_libburn_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "libburn",
-			       _("Libburn burns CD(RW), DVD+/-(RW)"),
+			       _("libburn burns CD(RW), DVD+/-(RW)"),
 			       "Philippe Rouquier",
 			       15);
 
 	/* libburn has no OVERBURN capabilities */
 
 	/* CD(R)W */
-	BRASERO_PLUGIN_ADD_STANDARD_CDR_FLAGS (plugin, BRASERO_BURN_FLAG_OVERBURN);
-	BRASERO_PLUGIN_ADD_STANDARD_CDRW_FLAGS (plugin, BRASERO_BURN_FLAG_OVERBURN);
+	/* Use DAO for first session since AUDIO need it to write CD-TEXT
+	 * Though libburn is unable to write CD-TEXT.... */
+	/* Note: when burning multiple tracks to a CD (like audio for example)
+	 * in dummy mode with TAO libburn will fail probably because it does
+	 * not use a correct next writable address for the second track (it uses
+	 * the same as for track #1). So remove dummy mode.
+	 * This is probably the same reason why it fails at merging another
+	 * session to a data CD in dummy mode. */
+	BRASERO_PLUGIN_ADD_STANDARD_CDR_FLAGS (plugin,
+	                                       BRASERO_BURN_FLAG_OVERBURN|
+	                                       BRASERO_BURN_FLAG_DUMMY);
+	BRASERO_PLUGIN_ADD_STANDARD_CDRW_FLAGS (plugin,
+	                                        BRASERO_BURN_FLAG_OVERBURN|
+	                                        BRASERO_BURN_FLAG_DUMMY);
 
 	/* audio support for CDs only */
 	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_PIPE|
 					BRASERO_PLUGIN_IO_ACCEPT_FILE,
-					BRASERO_AUDIO_FORMAT_RAW|
-					BRASERO_AUDIO_FORMAT_44100);
+					BRASERO_AUDIO_FORMAT_RAW);
 	
 	output = brasero_caps_disc_new (media_cd);
 	brasero_plugin_link_caps (plugin, output, input);
@@ -954,15 +1014,15 @@ brasero_libburn_export_caps (BraseroPlugin *plugin, gchar **error)
 	brasero_plugin_link_caps (plugin, output, input);
 	g_slist_free (output);
 
-	BRASERO_PLUGIN_ADD_STANDARD_DVDR_PLUS_FLAGS (plugin, BRASERO_BURN_FLAG_OVERBURN);
-	BRASERO_PLUGIN_ADD_STANDARD_DVDR_FLAGS (plugin, BRASERO_BURN_FLAG_OVERBURN);
+	BRASERO_PLUGIN_ADD_STANDARD_DVDR_PLUS_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
+	BRASERO_PLUGIN_ADD_STANDARD_DVDR_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
 
 	/* ... and DVD-RW (sequential) */
 	output = brasero_caps_disc_new (media_dvd_rw);
 	brasero_plugin_link_caps (plugin, output, input);
 	g_slist_free (output);
 
-	BRASERO_PLUGIN_ADD_STANDARD_DVDRW_FLAGS (plugin, BRASERO_BURN_FLAG_OVERBURN);
+	BRASERO_PLUGIN_ADD_STANDARD_DVDRW_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
 
 	/* for DVD+/-RW restricted */
 	output = brasero_caps_disc_new (media_dvd_rw_plus);
@@ -970,8 +1030,8 @@ brasero_libburn_export_caps (BraseroPlugin *plugin, gchar **error)
 	g_slist_free (output);
 	g_slist_free (input);
 
-	BRASERO_PLUGIN_ADD_STANDARD_DVDRW_RESTRICTED_FLAGS (plugin, BRASERO_BURN_FLAG_OVERBURN);
-	BRASERO_PLUGIN_ADD_STANDARD_DVDRW_PLUS_FLAGS (plugin, BRASERO_BURN_FLAG_OVERBURN);
+	BRASERO_PLUGIN_ADD_STANDARD_DVDRW_RESTRICTED_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
+	BRASERO_PLUGIN_ADD_STANDARD_DVDRW_PLUS_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
 
 	/* add blank caps */
 	output = brasero_caps_disc_new (BRASERO_MEDIUM_CD|
