@@ -33,8 +33,6 @@
 
 #include <gtk/gtk.h>
 
-#include <gconf/gconf-client.h>
-
 #include "brasero-misc.h"
 
 #include "eggtreemultidnd.h"
@@ -60,7 +58,7 @@
 #include "brasero-session.h"
 
 #include "brasero-volume.h"
-
+#include "brasero-setting.h"
 
 typedef struct _BraseroDataDiscPrivate BraseroDataDiscPrivate;
 struct _BraseroDataDiscPrivate
@@ -124,7 +122,7 @@ static GtkActionEntry entries [] = {
 	{"ContextualMenu", NULL, N_("Menu")},
 	{"OpenFile", GTK_STOCK_OPEN, NULL, NULL, N_("Open the selected files"),
 	 G_CALLBACK (brasero_data_disc_open_activated_cb)},
-	{"RenameData", NULL, N_("R_ename..."), NULL, N_("Rename the selected file"),
+	{"RenameData", NULL, N_("R_ename…"), NULL, N_("Rename the selected file"),
 	 G_CALLBACK (brasero_data_disc_rename_activated_cb)},
 	{"DeleteData", GTK_STOCK_REMOVE, NULL, NULL, N_("Remove the selected files from the project"),
 	 G_CALLBACK (brasero_data_disc_delete_activated_cb)},
@@ -164,8 +162,6 @@ enum {
 	TARGET_URIS_LIST,
 };
 
-#define GCONF_COLUMN_KEY				"/apps/brasero/display/data_column"
-#define GCONF_COLUMN_ORDER_KEY		"/apps/brasero/display/data_sort_order"
 
 static GtkTargetEntry ntables_cd [] = {
 	{BRASERO_DND_TARGET_DATA_TRACK_REFERENCE_LIST, GTK_TARGET_SAME_WIDGET, TREE_MODEL_ROW},
@@ -215,7 +211,7 @@ brasero_data_disc_import_failure_dialog (BraseroDataDisc *disc,
 {
 	brasero_app_alert (brasero_app_get_default (),
 			   _("The session could not be imported."),
-			   error?error->message:_("An unknown error occured"),
+			   error?error->message:_("An unknown error occurred"),
 			   GTK_MESSAGE_WARNING);
 }
 
@@ -625,14 +621,14 @@ brasero_data_disc_image_uri_cb (BraseroTrackDataCfg *vfs,
 
 	name = brasero_utils_get_uri_name (uri);
 	/* Translators: %s is the name of the image */
-	string = g_strdup_printf (_("There is only one selected file (\"%s\"). It is the image of a disc and its contents can be burnt."), name);
+	string = g_strdup_printf (_("There is only one selected file (\"%s\"). It is the image of a disc and its contents can be burned"), name);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), string);
 	g_free (string);
 	g_free (name);
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Burn as _File"), GTK_RESPONSE_NO);
 
-	button = brasero_utils_make_button (_("Burn _Contents..."),
+	button = brasero_utils_make_button (_("Burn _Contents…"),
 	                                    NULL,
 					    "media-optical-burn",
 					    GTK_ICON_SIZE_BUTTON);
@@ -795,7 +791,7 @@ brasero_data_disc_name_collision_cb (BraseroTrackDataCfg *project,
 	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-	                                          _("A file with this name already exists in the folder.  Replacing it will overwrite its content (on the disc only)."));
+	                                          _("A file with this name already exists in the folder.  Replacing it will overwrite its content on the disc to be burnt."));
 
 	/* Translators: Keep means we're keeping the files that already existed
 	 * in the project.
@@ -842,7 +838,7 @@ brasero_data_disc_2G_file_cb (BraseroTrackDataCfg *project,
 	if (priv->reject_deep_files)
 		return FALSE;
 
-	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection and use the third version of ISO9660 standard to support it?"), name);
+	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection and use the third version of the ISO9660 standard to support it?"), name);
 	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
 				     GTK_BUTTONS_NONE,
@@ -850,9 +846,9 @@ brasero_data_disc_2G_file_cb (BraseroTrackDataCfg *project,
 	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("The size of the file is over 2 GiB. Files larger than 2 GiB are not supported by ISO9660 standard in its first and second versions (the most widespread ones)."
-						    "\nIt is recommended to use the third version of ISO9660 standard which is supported by most of the operating systems including Linux and all versions of Windows ©."
-						    "\nHowever MacOS X cannot read images created with version 3 of ISO9660 standard."));
+						  _("The size of the file is over 2 GiB. Files larger than 2 GiB are not supported by the ISO9660 standard in its first and second versions (the most widespread ones)."
+						    "\nIt is recommended to use the third version of the ISO9660 standard, which is supported by most operating systems, including Linux and all versions of Windows ©."
+						    "\nHowever, Mac OS X cannot read images created with version 3 of the ISO9660 standard."));
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Ne_ver Add Such File"), GTK_RESPONSE_REJECT);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
@@ -897,7 +893,7 @@ brasero_data_disc_deep_directory_cb (BraseroTrackDataCfg *project,
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 						  _("The children of this directory will have 7 parent directories."
 						    "\nBrasero can create an image of such a file hierarchy and burn it; but the disc may not be readable on all operating systems."
-						    "\nNOTE: Such a file hierarchy is known to work on linux."));
+						    "\nNote: Such a file hierarchy is known to work on Linux."));
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Ne_ver Add Such File"), GTK_RESPONSE_REJECT);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
@@ -1116,7 +1112,7 @@ brasero_data_disc_session_available_cb (BraseroTrackDataCfg *session,
 		/* ask user */
 		volume_name = brasero_volume_get_name (BRASERO_VOLUME (medium));
 		/* Translators: %s is the name of the volume to import */
-		string = g_strdup_printf (_("Do you want to import the session from \'%s\'?"), volume_name);
+		string = g_strdup_printf (_("Do you want to import the session from \"%s\"?"), volume_name);
 		message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message),
 						      string,
 						      _("That way, old files from previous sessions will be usable after burning."),
@@ -1307,20 +1303,16 @@ brasero_data_disc_sort_column_changed (GtkTreeSortable *sortable,
                                        BraseroDataDisc *disc)
 {
 	GtkSortType sort_order;
-	GConfClient *client;
 	gint sort_column;
 
 	gtk_tree_sortable_get_sort_column_id (sortable, &sort_column, &sort_order);
 
-	client = gconf_client_get_default ();
-	gconf_client_set_int (client,
-	                      GCONF_COLUMN_KEY,
-	                      sort_column,
-	                      NULL);
-	gconf_client_set_int (client,
-	                      GCONF_COLUMN_ORDER_KEY,
-	                      sort_order,
-	                      NULL);
+	brasero_setting_set_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_DATA_DISC_COLUMN,
+	                           GINT_TO_POINTER (sort_column));
+	brasero_setting_set_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_DATA_DISC_COLUMN_ORDER,
+	                           GINT_TO_POINTER (sort_order));
 }
 
 static BraseroDiscResult
@@ -1331,21 +1323,22 @@ brasero_data_disc_set_track (BraseroDataDisc *disc,
 	BraseroDataDiscPrivate *priv;
 	BraseroStatus *status;
 	GtkWidget *message;
-	GConfClient *client;
 	gint sort_column;
+	gpointer value;
 	gint sort_order;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (disc);
 
 	priv->project = g_object_ref (track);
 
-	client = gconf_client_get_default ();
-	sort_column = gconf_client_get_int (client,
-	                                    GCONF_COLUMN_KEY,
-	                                    NULL);
-	sort_order = gconf_client_get_int (client,
-	                                   GCONF_COLUMN_ORDER_KEY,
-	                                   NULL);
+	brasero_setting_get_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_DATA_DISC_COLUMN,
+	                           &value);
+	sort_column = GPOINTER_TO_INT (value);
+	brasero_setting_get_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_DATA_DISC_COLUMN_ORDER,
+	                           &value);
+	sort_order = GPOINTER_TO_INT (value);
 
 	if ((sort_column == BRASERO_DATA_TREE_MODEL_SIZE
 	||   sort_column == BRASERO_DATA_TREE_MODEL_MIME_DESC
@@ -1355,7 +1348,6 @@ brasero_data_disc_set_track (BraseroDataDisc *disc,
 		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (track),
 						      sort_column,
 						      sort_order);
-	g_object_unref (client);
 
 	/* filtered files */
 	priv->filter = brasero_file_filtered_new (priv->project);
