@@ -94,7 +94,7 @@ struct _BraseroDiscIface {
 							 GtkWidget *message);
 };
 
-GType brasero_disc_get_type ();
+GType brasero_disc_get_type (void);
 
 guint
 brasero_disc_add_ui (BraseroDisc *disc,
@@ -133,6 +133,4 @@ brasero_disc_is_empty (BraseroDisc *disc);
 void
 brasero_disc_selection_changed (BraseroDisc *disc);
 
-G_END_DECLS
-
 #endif /* DISC_H */
