@@ -38,6 +38,7 @@
 
 #include "eggtreemultidnd.h"
 
+#include "brasero-setting.h"
 #include "brasero-file-chooser.h"
 #include "brasero-uri-container.h"
 #include "brasero-layout-object.h"
@@ -123,9 +124,92 @@ brasero_file_chooser_class_init (BraseroFileChooserClass *klass)
 	object_class->finalize = brasero_file_chooser_finalize;
 }
 
+static void
+brasero_file_chooser_paned_destroy (GObject *object,
+                                                      gpointer NULL_data)
+{
+	if (GPOINTER_TO_INT (g_object_get_data (object, "is-stock-file-chooser")))
+		brasero_setting_set_value (brasero_setting_get_default (),
+		                           BRASERO_SETTING_STOCK_FILE_CHOOSER_PERCENT,
+		                           g_object_get_data (object, "position-percent"));
+	else
+		brasero_setting_set_value (brasero_setting_get_default (),
+		                           BRASERO_SETTING_BRASERO_FILE_CHOOSER_PERCENT,
+		                           g_object_get_data (object, "position-percent"));
+}
+
+static void
+brasero_file_chooser_paned_map_event (GtkWidget *widget,
+                                      GdkEvent *event,
+                                      gpointer NULL_data)
+{
+	gint position;
+	gpointer percent;
+	GtkWidget *toplevel;
+
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (widget));
+	if (G_TYPE_FROM_INSTANCE (toplevel) == GTK_TYPE_FILE_CHOOSER_DIALOG) {
+		g_object_set_data (G_OBJECT (widget), "is-stock-file-chooser", GINT_TO_POINTER (1));
+		brasero_setting_get_value (brasero_setting_get_default (),
+		                           BRASERO_SETTING_STOCK_FILE_CHOOSER_PERCENT,
+		                           &percent);
+	}
+	else
+		brasero_setting_get_value (brasero_setting_get_default (),
+		                           BRASERO_SETTING_BRASERO_FILE_CHOOSER_PERCENT,
+		                           &percent);
+
+	if (GPOINTER_TO_INT (percent) < 0) {
+		/* No value so set something sane */
+		percent = GINT_TO_POINTER (30);
+	}
+
+	position = widget->allocation.width * GPOINTER_TO_INT (percent) / 100;
+	gtk_paned_set_position (GTK_PANED (widget), position);
+}
+
+static void
+brasero_file_chooser_position_percent (GObject *object,
+                                       gint width,
+                                       gint position)
+{
+	gint percent;
+
+	percent = position * 100 / width;
+	g_object_set_data (object, "position-percent", GINT_TO_POINTER (percent));
+}
+
+static void
+brasero_file_chooser_position_changed (GObject *object,
+                                       GParamSpec *param_spec,
+                                       gpointer NULL_data)
+{
+	gint position;
+	gint width;
+
+	position = gtk_paned_get_position (GTK_PANED (object));
+	width = GTK_WIDGET (object)->allocation.width;
+	brasero_file_chooser_position_percent (object, width, position);
+}
+
+static void
+brasero_file_chooser_allocation_changed (GObject *object,
+                                         GtkAllocation *allocation,
+                                         gpointer NULL_data)
+{
+	gint position;
+	gint width;
+
+	position = gtk_paned_get_position (GTK_PANED (object));
+	width = allocation->width;
+
+	brasero_file_chooser_position_percent (object, width, position);
+}
+
 void
 brasero_file_chooser_customize (GtkWidget *widget, gpointer null_data)
 {
+
 	/* we explore everything until we reach a treeview (there are two) */
 	if (GTK_IS_TREE_VIEW (widget)) {
 		GtkTargetList *list;
@@ -140,10 +224,8 @@ brasero_file_chooser_customize (GtkWidget *widget, gpointer null_data)
 		 * the warning messages we get if we do */
 
 		if (found
-		&&  gtk_tree_selection_get_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (widget))) == GTK_SELECTION_MULTIPLE) {
-			gtk_tree_view_set_rubber_banding (GTK_TREE_VIEW (widget), TRUE);
+		&&  gtk_tree_selection_get_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (widget))) == GTK_SELECTION_MULTIPLE)
 			egg_tree_multi_drag_add_drag_support (GTK_TREE_VIEW (widget));
-		}
 	}
 	else if (GTK_IS_BUTTON (widget)) {
 		GtkWidget *image;
@@ -175,6 +257,40 @@ brasero_file_chooser_customize (GtkWidget *widget, gpointer null_data)
 		}
 	}
 	else if (GTK_IS_CONTAINER (widget)) {
+		if (GTK_IS_PANED (widget)) {
+			GtkWidget *left;
+
+			/* This is to allow the left part to be shrunk as much 
+			 * as the user want. */
+			left = gtk_paned_get_child1 (GTK_PANED (widget));
+
+			g_object_ref (left);
+			gtk_container_remove (GTK_CONTAINER (widget), left);
+			gtk_paned_pack1 (GTK_PANED (widget),
+					 left,
+					 TRUE,
+					 TRUE);
+			g_object_unref (left);
+
+			g_signal_connect (widget,
+			                  "notify::position",
+			                  G_CALLBACK (brasero_file_chooser_position_changed),
+			                  NULL);
+
+			g_signal_connect (widget,
+			                  "size-allocate",
+			                  G_CALLBACK (brasero_file_chooser_allocation_changed),
+			                  NULL);
+
+			g_signal_connect (widget,
+			                  "destroy",
+			                  G_CALLBACK (brasero_file_chooser_paned_destroy),
+			                  NULL);
+			g_signal_connect (widget,
+			                  "map-event",
+			                  G_CALLBACK (brasero_file_chooser_paned_map_event),
+			                  NULL);
+		}
 		gtk_container_foreach (GTK_CONTAINER (widget),
 				       brasero_file_chooser_customize,
 				       NULL);
@@ -214,7 +330,7 @@ brasero_file_chooser_init (BraseroFileChooser *obj)
 	obj->priv->filter_any = filter;
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, _("Audio files only"));
+	gtk_file_filter_set_name (filter, _("Audio files"));
 	gtk_file_filter_add_mime_type (filter, "audio/*");
 	gtk_file_filter_add_mime_type (filter, "application/ogg");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (obj->priv->chooser), filter);
@@ -222,7 +338,7 @@ brasero_file_chooser_init (BraseroFileChooser *obj)
 	obj->priv->filter_audio = filter;
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, _("Movies only"));
+	gtk_file_filter_set_name (filter, _("Movies"));
 	gtk_file_filter_add_mime_type (filter, "video/*");
 	gtk_file_filter_add_mime_type (filter, "application/ogg");
 	gtk_file_filter_add_mime_type (filter, "application/x-flash-video");
@@ -232,7 +348,7 @@ brasero_file_chooser_init (BraseroFileChooser *obj)
 
 	filter = gtk_file_filter_new ();
 	/* Translators: this is an image, a picture, not a "Disc Image" */
-	gtk_file_filter_set_name (filter, C_("picture", "Image files only"));
+	gtk_file_filter_set_name (filter, C_("picture", "Image files"));
 	gtk_file_filter_add_mime_type (filter, "image/*");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (obj->priv->chooser), filter);
 
