@@ -3,16 +3,16 @@
  *
  *  Wed Sep 27 17:34:41 2006
  *  Copyright  2006  Rouquier Philippe
- *  <Rouquier Philippe@localhost.localdomain>
+ *  <bonfire-app@wanadoo.fr>
  ****************************************************************************/
 
 /*
- * This program is free software; you can redistribute it and/or modify
+ * Brasero is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  * 
- * This program is distributed in the hope that it will be useful,
+ * Brasero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
@@ -22,12 +22,11 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
  */
 
-#include <gtk/gtktreestore.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtktreemodelsort.h>
-#include <gtk/gtktreemodelfilter.h>
-#include <gtk/gtktreednd.h>
+#include <gtk/gtk.h>
 
+#include "brasero-multi-dnd.h"
+
+#include "brasero-track-data-cfg.h"
 #include "eggtreemultidnd.h"
 
 static gboolean
@@ -128,6 +127,72 @@ static const GInterfaceInfo multi_DND_drag_source_info = {
 	NULL
 };
 
+static gboolean
+brasero_data_track_cfg_multi_DND_row_draggable (EggTreeMultiDragSource *drag_source,
+						GList *path_list)
+{
+	GList *iter;
+
+	/* at least one row must not be an imported row. */
+	for (iter = path_list; iter && iter->data; iter = iter->next) {
+		GtkTreePath *path;
+		GtkTreeRowReference *reference;
+
+		reference = iter->data;
+		path = gtk_tree_row_reference_get_path (reference);
+		if (gtk_tree_drag_source_row_draggable (GTK_TREE_DRAG_SOURCE (drag_source), path)) {
+			gtk_tree_path_free (path);
+			return TRUE;
+		}
+		gtk_tree_path_free (path);
+	}
+
+	return FALSE;
+}
+
+static gboolean
+brasero_data_track_cfg_multi_DND_drag_data_get (EggTreeMultiDragSource *drag_source,
+						GList *path_list,
+						GtkSelectionData *selection_data)
+{
+	if (selection_data->target == gdk_atom_intern (BRASERO_DND_TARGET_DATA_TRACK_REFERENCE_LIST, TRUE)) {
+		gtk_selection_data_set (selection_data,
+					gdk_atom_intern_static_string (BRASERO_DND_TARGET_DATA_TRACK_REFERENCE_LIST),
+					8,
+					(void *) path_list,
+					sizeof (GList));
+	}
+	else
+		return FALSE;
+
+	return TRUE;
+}
+
+static gboolean
+brasero_data_track_cfg_multi_DND_drag_data_delete (EggTreeMultiDragSource *drag_source,
+						   GList *path_list)
+{
+	/* NOTE: it's not the data in the selection_data here that should be
+	 * deleted but rather the rows selected when there is a move. FALSE
+	 * here means that we didn't delete anything. */
+	/* return TRUE to stop other handlers */
+	return TRUE;
+}
+
+static void
+brasero_data_track_cfg_multi_DND_drag_source_init (EggTreeMultiDragSourceIface *iface)
+{
+	iface->row_draggable = brasero_data_track_cfg_multi_DND_row_draggable;
+	iface->drag_data_get = brasero_data_track_cfg_multi_DND_drag_data_get;
+	iface->drag_data_delete = brasero_data_track_cfg_multi_DND_drag_data_delete;
+}
+
+static const GInterfaceInfo brasero_data_track_cfg_multi_DND_drag_source_info = {
+	(GInterfaceInitFunc) brasero_data_track_cfg_multi_DND_drag_source_init,
+	NULL,
+	NULL
+};
+
 void
 brasero_enable_multi_DND (void)
 {
@@ -152,5 +217,9 @@ brasero_enable_multi_DND (void)
 	g_type_add_interface_static (object_type,
 				     EGG_TYPE_TREE_MULTI_DRAG_SOURCE,
 				     &multi_DND_drag_source_info);
+
+	g_type_add_interface_static (BRASERO_TYPE_TRACK_DATA_CFG,
+				     EGG_TYPE_TREE_MULTI_DRAG_SOURCE,
+				     &brasero_data_track_cfg_multi_DND_drag_source_info);
 }
  
