@@ -37,14 +37,12 @@
 
 #include <gtk/gtk.h>
 
-#include <gconf/gconf-client.h>
-
 #include <gst/gst.h>
 #include <gst/interfaces/xoverlay.h>
 
 #include "brasero-player-bacon.h"
-#include "burn-debug.h"
- 
+#include "brasero-setting.h"
+
 static void brasero_player_bacon_class_init(BraseroPlayerBaconClass *klass);
 static void brasero_player_bacon_init(BraseroPlayerBacon *sp);
 static void brasero_player_bacon_finalize(GObject *object);
@@ -366,19 +364,14 @@ brasero_player_bacon_destroy (GtkObject *obj)
 
 	/* save volume */
 	if (cobj->priv->pipe) {
-		GConfClient *client;
 		gdouble volume;
 
-		client = gconf_client_get_default ();
 		g_object_get (cobj->priv->pipe,
 			      "volume", &volume,
 			      NULL);
-
-		volume = gconf_client_set_int (client,
-					       GCONF_PLAYER_VOLUME,
-					       (gint) (volume * 100.0),
-					       NULL);
-		g_object_unref (client);
+		brasero_setting_set_value (brasero_setting_get_default (),
+		                           BRASERO_SETTING_PLAYER_VOLUME,
+		                           GINT_TO_POINTER (volume * 100));
 	}
 
 	if (cobj->priv->xoverlay
@@ -557,7 +550,7 @@ brasero_player_bacon_bus_messages (GstBus *bus,
 
 	case GST_MESSAGE_ERROR:
 		gst_message_parse_error (msg, &error, NULL);
-		BRASERO_BURN_LOG ("%s", error->message);
+		g_warning ("%s", error->message);
 
 		g_signal_emit (bacon,
 			       brasero_player_bacon_signals [STATE_CHANGED_SIGNAL],
@@ -677,12 +670,12 @@ brasero_player_bacon_setup_pipe (BraseroPlayerBacon *bacon)
 {
 	GstElement *video_sink, *audio_sink;
 	GstBus *bus = NULL;
-	GConfClient *client;
 	gdouble volume;
+	gpointer value;
 
 	bacon->priv->pipe = gst_element_factory_make ("playbin", NULL);
 	if (!bacon->priv->pipe) {
-		BRASERO_BURN_LOG ("Pipe creation error : can't create pipe.\n");
+		g_warning ("Pipe creation error : can't create pipe.\n");
 		return;
 	}
 
@@ -718,18 +711,19 @@ brasero_player_bacon_setup_pipe (BraseroPlayerBacon *bacon)
 	gst_object_unref (bus);
 
 	/* set saved volume */
-	client = gconf_client_get_default ();
-	volume = gconf_client_get_int (client, GCONF_PLAYER_VOLUME, NULL);
+	brasero_setting_get_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_PLAYER_VOLUME,
+	                           &value);
+	volume = GPOINTER_TO_INT (value);
 	volume = CLAMP (volume, 0, 500);
 	g_object_set (bacon->priv->pipe,
 		      "volume", (gdouble) volume / 100.0,
 		      NULL);
-	g_object_unref (client);
 
 	return;
 
 error:
-	BRASERO_BURN_LOG ("player creation error");
+	g_warning ("player creation error");
 	brasero_player_bacon_clear_pipe (bacon);
 	g_signal_emit (bacon,
 		       brasero_player_bacon_signals [STATE_CHANGED_SIGNAL],
