@@ -437,7 +437,7 @@ brasero_playlist_destroy (GtkObject *object)
 	 * raise problems since the GdkWindow has been destroyed */
 	if (playlist->priv->parse_type) {
 		brasero_io_cancel_by_base (playlist->priv->parse_type);
-		brasero_io_job_base_free (playlist->priv->parse_type);
+		g_free (playlist->priv->parse_type);
 		playlist->priv->parse_type = NULL;
 	}
 
@@ -613,15 +613,6 @@ brasero_playlist_get_selected_uri (BraseroURIContainer *container)
 	return NULL;
 }
 
-void
-brasero_playlist_unselect_all (BraseroPlaylist *playlist)
-{
-	GtkTreeSelection *selection;
-
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (playlist->priv->tree));
-	gtk_tree_selection_unselect_all (selection);
-}
-
 static void
 brasero_playlist_add_cb (GtkButton *button, BraseroPlaylist *playlist)
 {
@@ -803,7 +794,7 @@ brasero_playlist_dialog_error (BraseroPlaylist *playlist, const gchar *uri)
 	primary = g_strdup_printf (_("Error parsing playlist \"%s\"."), name);
 	brasero_app_alert (brasero_app_get_default (),
 			   primary,
-			   _("An unknown error occured"),
+			   _("An unknown error occurred"),
 			   GTK_MESSAGE_ERROR);
 	g_free (primary);
 	g_free (name);
@@ -946,7 +937,7 @@ brasero_playlist_insert (BraseroPlaylist *playlist, const gchar *uri)
 	gtk_tree_store_set (GTK_TREE_STORE (model), &parent,
 			    BRASERO_PLAYLIST_DISPLAY_COL, name,
 			    BRASERO_PLAYLIST_URI_COL, uri,
-			    BRASERO_PLAYLIST_NB_SONGS_COL, _("(loading ...)"),
+			    BRASERO_PLAYLIST_NB_SONGS_COL, _("(loading…)"),
 			    -1);
 	g_free (name);
 
