@@ -337,7 +337,7 @@ brasero_video_tree_model_get_value (GtkTreeModel *model,
 			g_free (text);
 		}
 		else
-			g_value_set_string (value, _("(loading ...)"));
+			g_value_set_string (value, _("(loading…)"));
 
 		brasero_status_free (status);
 		return;
@@ -839,25 +839,22 @@ brasero_video_tree_model_drag_data_received (GtkTreeDragDest *drag_dest,
 
 	/* The new row(s) must be before dest_path but after our sibling */
 	sibling = brasero_video_tree_model_path_to_track (BRASERO_VIDEO_TREE_MODEL (drag_dest), dest_path);
-
+		
 	/* Received data: see where it comes from:
 	 * - from us, then that's a simple move
 	 * - from another widget then it's going to be URIS and we add
 	 *   them to VideoProject */
 	if (selection_data->target == gdk_atom_intern (BRASERO_DND_TARGET_SELF_FILE_NODES, TRUE)) {
 		BraseroDNDVideoContext *context;
-		GtkTreeRowReference *dest;
 		GList *iter;
 
 		context = (BraseroDNDVideoContext *) selection_data->data;
 		if (context->model != GTK_TREE_MODEL (drag_dest))
 			return TRUE;
 
-		dest = gtk_tree_row_reference_new (GTK_TREE_MODEL (drag_dest), dest_path);
 		/* That's us: move the row and its children. */
 		for (iter = context->references; iter; iter = iter->next) {
 			GtkTreeRowReference *reference;
-			GtkTreePath *destination;
 			GtkTreePath *treepath;
 			GtkTreeIter tree_iter;
 
@@ -868,39 +865,23 @@ brasero_video_tree_model_drag_data_received (GtkTreeDragDest *drag_dest,
 						 treepath);
 			gtk_tree_path_free (treepath);
 
-			destination = gtk_tree_row_reference_get_path (dest);
 			brasero_video_tree_model_move_before (BRASERO_VIDEO_TREE_MODEL (drag_dest),
 							      &tree_iter,
-							      destination);
-			gtk_tree_path_free (destination);
+							      dest_path);
 		}
-		gtk_tree_row_reference_free (dest);
 	}
 	else if (selection_data->target == gdk_atom_intern ("text/uri-list", TRUE)) {
 		gint i;
-		gchar **uris = NULL;
+		gchar **uris;
 		gboolean success = FALSE;
-		const guchar *selection_data_raw;
-
-		/* NOTE: for some reason gdk_text_property_to_utf8_list_for_display ()
-		 * fails with banshee DND URIs list when calling gtk_selection_data_get_uris ().
-		 * so do like nautilus */
 
 		/* NOTE: there can be many URIs at the same time. One
 		 * success is enough to return TRUE. */
-		selection_data_raw = gtk_selection_data_get_data (selection_data);
+		success = FALSE;
 		uris = gtk_selection_data_get_uris (selection_data);
-		if (!uris) {
-			const guchar *selection_data_raw;
-
-			selection_data_raw = gtk_selection_data_get_data (selection_data);
-			uris = g_uri_list_extract_uris ((gchar *) selection_data_raw);
-		}
-
 		if (!uris)
 			return TRUE;
 
-		success = FALSE;
 		for (i = 0; uris [i]; i ++) {
 			BraseroTrackStreamCfg *track;
 
